/*!
* ZeroClipboard
* The ZeroClipboard library provides an easy way to copy text to the clipboard using an invisible Adobe Flash movie and a JavaScript interface.
* Copyright (c) 2014 Jon Rohan, James M. Greene
* Licensed MIT
* http://zeroclipboard.org/
* v2.0.0-alpha.2
*/
(function (window) {
    "use strict";
    var currentElement;
    var flashState = {
        bridge: null,
        version: "0.0.0",
        pluginType: "unknown",
        disabled: null,
        outdated: null,
        deactivated: null,
        overdue: null,
        ready: null
    };
    var _clipData = {};
    var clientIdCounter = 0;
    var _clientMeta = {};
    var elementIdCounter = 0;
    var _elementMeta = {};
    var _amdModuleId = null;
    var _cjsModuleId = null;
    var _swfPath = function () {
        var i, jsDir, tmpJsPath, jsPath, swfPath = "ZeroClipboard.swf";
        if (document.currentScript && (jsPath = document.currentScript.src)) { } else {
            var scripts = document.getElementsByTagName("script");
            if ("readyState" in scripts[0]) {
                for (i = scripts.length; i--;) {
                    if (scripts[i].readyState === "interactive" && (jsPath = scripts[i].src)) {
                        break;
                    }
                }
            } else if (document.readyState === "loading") {
                jsPath = scripts[scripts.length - 1].src;
            } else {
                for (i = scripts.length; i--;) {
                    tmpJsPath = scripts[i].src;
                    if (!tmpJsPath) {
                        jsDir = null;
                        break;
                    }
                    tmpJsPath = tmpJsPath.split("#")[0].split("?")[0];
                    tmpJsPath = tmpJsPath.slice(0, tmpJsPath.lastIndexOf("/") + 1);
                    if (jsDir == null) {
                        jsDir = tmpJsPath;
                    } else if (jsDir !== tmpJsPath) {
                        jsDir = null;
                        break;
                    }
                }
                if (jsDir !== null) {
                    jsPath = jsDir;
                }
            }
        }
        if (jsPath) {
            jsPath = jsPath.split("#")[0].split("?")[0];
            swfPath = jsPath.slice(0, jsPath.lastIndexOf("/") + 1) + swfPath;
        }
        return swfPath;
    }();
    var _camelizeCssPropName = function () {
        var matcherRegex = /\-([a-z])/g, replacerFn = function (match, group) {
            return group.toUpperCase();
        };
        return function (prop) {
            return prop.replace(matcherRegex, replacerFn);
        };
    }();
    var _getStyle = function (el, prop) {
        var value, camelProp, tagName, possiblePointers, i, len;
        if (window.getComputedStyle) {
            value = window.getComputedStyle(el, null).getPropertyValue(prop);
        } else {
            camelProp = _camelizeCssPropName(prop);
            if (el.currentStyle) {
                value = el.currentStyle[camelProp];
            } else {
                value = el.style[camelProp];
            }
        }
        if (prop === "cursor") {
            if (!value || value === "auto") {
                tagName = el.tagName.toLowerCase();
                if (tagName === "a") {
                    return "pointer";
                }
            }
        }
        return value;
    };
    var _elementMouseOver = function (event) {
        if (!event) {
            event = window.event;
        }
        var target;
        if (this !== window) {
            target = this;
        } else if (event.target) {
            target = event.target;
        } else if (event.srcElement) {
            target = event.srcElement;
        }
        ZeroClipboard.activate(target);
    };
    var _addEventHandler = function (element, method, func) {
        if (!element || element.nodeType !== 1) {
            return;
        }
        if (element.addEventListener) {
            element.addEventListener(method, func, false);
        } else if (element.attachEvent) {
            element.attachEvent("on" + method, func);
        }
    };
    var _removeEventHandler = function (element, method, func) {
        if (!element || element.nodeType !== 1) {
            return;
        }
        if (element.removeEventListener) {
            element.removeEventListener(method, func, false);
        } else if (element.detachEvent) {
            element.detachEvent("on" + method, func);
        }
    };
    var _addClass = function (element, value) {
        if (!element || element.nodeType !== 1) {
            return element;
        }
        if (element.classList) {
            if (!element.classList.contains(value)) {
                element.classList.add(value);
            }
            return element;
        }
        if (value && typeof value === "string") {
            var classNames = (value || "").split(/\s+/);
            if (element.nodeType === 1) {
                if (!element.className) {
                    element.className = value;
                } else {
                    var className = " " + element.className + " ", setClass = element.className;
                    for (var c = 0, cl = classNames.length; c < cl; c++) {
                        if (className.indexOf(" " + classNames[c] + " ") < 0) {
                            setClass += " " + classNames[c];
                        }
                    }
                    element.className = setClass.replace(/^\s+|\s+$/g, "");
                }
            }
        }
        return element;
    };
    var _removeClass = function (element, value) {
        if (!element || element.nodeType !== 1) {
            return element;
        }
        if (element.classList) {
            if (element.classList.contains(value)) {
                element.classList.remove(value);
            }
            return element;
        }
        if (value && typeof value === "string" || value === undefined) {
            var classNames = (value || "").split(/\s+/);
            if (element.nodeType === 1 && element.className) {
                if (value) {
                    var className = (" " + element.className + " ").replace(/[\n\t]/g, " ");
                    for (var c = 0, cl = classNames.length; c < cl; c++) {
                        className = className.replace(" " + classNames[c] + " ", " ");
                    }
                    element.className = className.replace(/^\s+|\s+$/g, "");
                } else {
                    element.className = "";
                }
            }
        }
        return element;
    };
    var _getZoomFactor = function () {
        var rect, physicalWidth, logicalWidth, zoomFactor = 1;
        if (typeof document.body.getBoundingClientRect === "function") {
            rect = document.body.getBoundingClientRect();
            physicalWidth = rect.right - rect.left;
            logicalWidth = document.body.offsetWidth;
            zoomFactor = Math.round(physicalWidth / logicalWidth * 100) / 100;
        }
        return zoomFactor;
    };
    var _getDOMObjectPosition = function (obj, defaultZIndex) {
        var info = {
            left: 0,
            top: 0,
            width: 0,
            height: 0,
            zIndex: _getSafeZIndex(defaultZIndex) - 1
        };
        if (obj.getBoundingClientRect) {
            var rect = obj.getBoundingClientRect();
            var pageXOffset, pageYOffset, zoomFactor;
            if ("pageXOffset" in window && "pageYOffset" in window) {
                pageXOffset = window.pageXOffset;
                pageYOffset = window.pageYOffset;
            } else {
                zoomFactor = _getZoomFactor();
                pageXOffset = Math.round(document.documentElement.scrollLeft / zoomFactor);
                pageYOffset = Math.round(document.documentElement.scrollTop / zoomFactor);
            }
            var leftBorderWidth = document.documentElement.clientLeft || 0;
            var topBorderWidth = document.documentElement.clientTop || 0;
            info.left = rect.left + pageXOffset - leftBorderWidth;
            info.top = rect.top + pageYOffset - topBorderWidth;
            info.width = "width" in rect ? rect.width : rect.right - rect.left;
            info.height = "height" in rect ? rect.height : rect.bottom - rect.top;
        }
        return info;
    };
    var _cacheBust = function (path, options) {
        var cacheBust = options == null || options && options.cacheBust === true;
        if (cacheBust) {
            return (path.indexOf("?") === -1 ? "?" : "&") + "noCache=" + new Date().getTime();
        } else {
            return "";
        }
    };
    var _vars = function (options) {
        var i, len, domain, domains, str = [], trustedOriginsExpanded = [];
        if (options.trustedDomains) {
            if (typeof options.trustedDomains === "string") {
                domains = [options.trustedDomains];
            } else if (typeof options.trustedDomains === "object" && "length" in options.trustedDomains) {
                domains = options.trustedDomains;
            }
        }
        if (domains && domains.length) {
            for (i = 0, len = domains.length; i < len; i++) {
                if (domains.hasOwnProperty(i) && domains[i] && typeof domains[i] === "string") {
                    domain = _extractDomain(domains[i]);
                    _log("Trusted domain: " + domain, options.debug);
                    if (!domain) {
                        continue;
                    }
                    if (domain === "*") {
                        trustedOriginsExpanded = [domain];
                        break;
                    }
                    trustedOriginsExpanded.push.apply(trustedOriginsExpanded, [domain, "//" + domain, window.location.protocol + "//" + domain]);
                }
            }
        }
        if (trustedOriginsExpanded.length) {
            str.push("trustedOrigins=" + encodeURIComponent(trustedOriginsExpanded.join(",")));
        }
        if (typeof options.jsModuleId === "string" && options.jsModuleId) {
            str.push("jsModuleId=" + encodeURIComponent(options.jsModuleId));
        }
        return str.join("&");
    };
    var _inArray = function (elem, array, fromIndex) {
        if (typeof array.indexOf === "function") {
            return array.indexOf(elem, fromIndex);
        }
        var i, len = array.length;
        if (typeof fromIndex === "undefined") {
            fromIndex = 0;
        } else if (fromIndex < 0) {
            fromIndex = len + fromIndex;
        }
        for (i = fromIndex; i < len; i++) {
            if (array.hasOwnProperty(i) && array[i] === elem) {
                return i;
            }
        }
        return -1;
    };
    var _prepClip = function (elements) {
        if (typeof elements === "string") throw new TypeError("ZeroClipboard doesn't accept query strings.");
        if (!elements.length) return [elements];
        return elements;
    };
    var _dispatchCallback = function (func, context, args, async) {
        if (async) {
            window.setTimeout(function () {
                func.apply(context, args);
            }, 0);
        } else {
            func.apply(context, args);
        }
    };
    var _getSafeZIndex = function (val) {
        var zIndex, tmp;
        if (val) {
            if (typeof val === "number" && val > 0) {
                zIndex = val;
            } else if (typeof val === "string" && (tmp = parseInt(val, 10)) && !isNaN(tmp) && tmp > 0) {
                zIndex = tmp;
            }
        }
        if (!zIndex) {
            if (typeof _globalConfig.zIndex === "number" && _globalConfig.zIndex > 0) {
                zIndex = _globalConfig.zIndex;
            } else if (typeof _globalConfig.zIndex === "string" && (tmp = parseInt(_globalConfig.zIndex, 10)) && !isNaN(tmp) && tmp > 0) {
                zIndex = tmp;
            }
        }
        return zIndex || 0;
    };
    var _deprecationWarning = function (deprecatedApiName, debugEnabled) {
        if (deprecatedApiName) {
            var deprecationWarning = "`" + deprecatedApiName + "` is deprecated. See docs for more info:\n" + "    https://github.com/zeroclipboard/zeroclipboard/blob/master/docs/instructions.md#deprecations";
            _log(deprecationWarning, debugEnabled);
        }
    };
    var _log = function (message, debugEnabled) {
        if (message && debugEnabled !== false && typeof console !== "undefined" && console && (console.warn || console.log)) {
            if (console.warn) {
                console.warn(message);
            } else {
                console.log(message);
            }
        }
    };
    var _extend = function () {
        var i, len, arg, prop, src, copy, target = arguments[0] || {};
        for (i = 1, len = arguments.length; i < len; i++) {
            if ((arg = arguments[i]) != null) {
                for (prop in arg) {
                    if (arg.hasOwnProperty(prop)) {
                        src = target[prop];
                        copy = arg[prop];
                        if (target === copy) {
                            continue;
                        }
                        if (copy !== undefined) {
                            target[prop] = copy;
                        }
                    }
                }
            }
        }
        return target;
    };
    var _extractDomain = function (originOrUrl) {
        if (originOrUrl == null || originOrUrl === "") {
            return null;
        }
        originOrUrl = originOrUrl.replace(/^\s+|\s+$/g, "");
        if (originOrUrl === "") {
            return null;
        }
        var protocolIndex = originOrUrl.indexOf("//");
        originOrUrl = protocolIndex === -1 ? originOrUrl : originOrUrl.slice(protocolIndex + 2);
        var pathIndex = originOrUrl.indexOf("/");
        originOrUrl = pathIndex === -1 ? originOrUrl : protocolIndex === -1 || pathIndex === 0 ? null : originOrUrl.slice(0, pathIndex);
        if (originOrUrl && originOrUrl.slice(-4).toLowerCase() === ".swf") {
            return null;
        }
        return originOrUrl || null;
    };
    var _determineScriptAccess = function () {
        var _extractAllDomains = function (origins, resultsArray) {
            var i, len, tmp;
            if (origins != null && resultsArray[0] !== "*") {
                if (typeof origins === "string") {
                    origins = [origins];
                }
                if (typeof origins === "object" && "length" in origins) {
                    for (i = 0, len = origins.length; i < len; i++) {
                        if (origins.hasOwnProperty(i)) {
                            tmp = _extractDomain(origins[i]);
                            if (tmp) {
                                if (tmp === "*") {
                                    resultsArray.length = 0;
                                    resultsArray.push("*");
                                    break;
                                }
                                if (_inArray(tmp, resultsArray) === -1) {
                                    resultsArray.push(tmp);
                                }
                            }
                        }
                    }
                }
            }
        };
        return function (currentDomain, configOptions) {
            var swfDomain = _extractDomain(configOptions.swfPath);
            if (swfDomain === null) {
                swfDomain = currentDomain;
            }
            var trustedDomains = [];
            _extractAllDomains(configOptions.trustedOrigins, trustedDomains);
            _extractAllDomains(configOptions.trustedDomains, trustedDomains);
            var len = trustedDomains.length;
            if (len > 0) {
                if (len === 1 && trustedDomains[0] === "*") {
                    return "always";
                }
                if (_inArray(currentDomain, trustedDomains) !== -1) {
                    if (len === 1 && currentDomain === swfDomain) {
                        return "sameDomain";
                    }
                    return "always";
                }
            }
            return "never";
        };
    }();
    var _objectKeys = function (obj) {
        if (obj == null) {
            return [];
        }
        if (Object.keys) {
            return Object.keys(obj);
        }
        var keys = [];
        for (var prop in obj) {
            if (obj.hasOwnProperty(prop)) {
                keys.push(prop);
            }
        }
        return keys;
    };
    var _deleteOwnProperties = function (obj) {
        if (obj) {
            for (var prop in obj) {
                if (obj.hasOwnProperty(prop)) {
                    delete obj[prop];
                }
            }
        }
        return obj;
    };
    var _safeActiveElement = function () {
        try {
            return document.activeElement;
        } catch (err) { }
        return null;
    };
    var _detectFlashSupport = function () {
        var hasFlash = false;
        var isActiveX = false;
        var flashVersion = "";
        var isPPAPI = false;
        function parseFlashVersion(desc) {
            var matches = desc.match(/[\d]+/g);
            matches.length = 3;
            return matches.join(".");
        }
        function isPepperFlash(flashPlayerFileName) {
            return !!flashPlayerFileName && (flashPlayerFileName = flashPlayerFileName.toLowerCase()) && (/^(pepflashplayer\.dll|libpepflashplayer\.so|pepperflashplayer\.plugin)$/.test(flashPlayerFileName) || flashPlayerFileName.slice(-13) === "chrome.plugin");
        }
        function inspectPlugin(plugin) {
            if (plugin) {
                hasFlash = true;
                if (plugin.version) {
                    flashVersion = parseFlashVersion(plugin.version);
                }
                if (!flashVersion && plugin.description) {
                    flashVersion = parseFlashVersion(plugin.description);
                }
                if (plugin.filename) {
                    isPPAPI = isPepperFlash(plugin.filename);
                }
            }
        }
        var plugin, ax, mimeType;
        if (navigator.plugins && navigator.plugins.length) {
            plugin = navigator.plugins["Shockwave Flash"];
            inspectPlugin(plugin);
            if (navigator.plugins["Shockwave Flash 2.0"]) {
                hasFlash = true;
                flashVersion = "2.0.0.11";
            }
        } else if (navigator.mimeTypes && navigator.mimeTypes.length) {
            mimeType = navigator.mimeTypes["application/x-shockwave-flash"];
            plugin = mimeType && mimeType.enabledPlugin;
            inspectPlugin(plugin);
        } else if (typeof ActiveXObject !== "undefined") {
            isActiveX = true;
            try {
                ax = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.7");
                hasFlash = true;
                flashVersion = parseFlashVersion(ax.GetVariable("$version"));
            } catch (e1) {
                try {
                    ax = new ActiveXObject("ShockwaveFlash.ShockwaveFlash.6");
                    hasFlash = true;
                    flashVersion = "6.0.21";
                } catch (e2) {
                    try {
                        ax = new ActiveXObject("ShockwaveFlash.ShockwaveFlash");
                        hasFlash = true;
                        flashVersion = parseFlashVersion(ax.GetVariable("$version"));
                    } catch (e3) {
                        isActiveX = false;
                    }
                }
            }
        }
        flashState.disabled = hasFlash !== true;
        flashState.outdated = flashVersion && parseFloat(flashVersion) < 11;
        flashState.version = flashVersion || "0.0.0";
        flashState.pluginType = isPPAPI ? "pepper" : isActiveX ? "activex" : hasFlash ? "netscape" : "unknown";
    };
    _detectFlashSupport();
    var ZeroClipboard = function (elements) {
        if (!(this instanceof ZeroClipboard)) {
            return new ZeroClipboard(elements);
        }
        this.id = "" + clientIdCounter++;
        _clientMeta[this.id] = {
            instance: this,
            elements: [],
            handlers: {}
        };
        if (elements) {
            this.clip(elements);
        }
        if (typeof flashState.ready !== "boolean") {
            flashState.ready = false;
        }
        if (!ZeroClipboard.isFlashUnusable() && flashState.bridge === null) {
            var _client = this;
            var maxWait = _globalConfig.flashLoadTimeout;
            if (typeof maxWait === "number" && maxWait >= 0) {
                setTimeout(function () {
                    if (typeof flashState.deactivated !== "boolean") {
                        flashState.deactivated = true;
                    }
                    if (flashState.deactivated === true) {
                        ZeroClipboard.emit({
                            type: "error",
                            name: "flash-deactivated",
                            client: _client
                        });
                    }
                }, maxWait);
            }
            flashState.overdue = false;
            _bridge();
        }
    };
    ZeroClipboard.prototype.setText = function (newText) {
        if (newText && newText !== "") {
            _clipData["text/plain"] = newText;
        }
        return this;
    };
    ZeroClipboard.prototype.setSize = function (width, height) {
        if (flashState.ready === true && flashState.bridge && typeof flashState.bridge.setSize === "function") {
            flashState.bridge.setSize(width, height);
        } else {
            flashState.ready = false;
        }
        return this;
    };
    var _setHandCursor = function (enabled) {
        if (flashState.ready === true && flashState.bridge && typeof flashState.bridge.setHandCursor === "function") {
            flashState.bridge.setHandCursor(enabled);
        } else {
            flashState.ready = false;
        }
    };
    ZeroClipboard.prototype.destroy = function () {
        this.unclip();
        this.off();
        delete _clientMeta[this.id];
    };
    var _getAllClients = function () {
        var i, len, client, clients = [], clientIds = _objectKeys(_clientMeta);
        for (i = 0, len = clientIds.length; i < len; i++) {
            client = _clientMeta[clientIds[i]].instance;
            if (client && client instanceof ZeroClipboard) {
                clients.push(client);
            }
        }
        return clients;
    };
    ZeroClipboard.version = "2.0.0-alpha.2";
    var _globalConfig = {
        swfPath: _swfPath,
        trustedDomains: window.location.host ? [window.location.host] : [],
        cacheBust: true,
        forceHandCursor: false,
        zIndex: 999999999,
        debug: false,
        title: null,
        autoActivate: true,
        flashLoadTimeout: 3e4
    };
    ZeroClipboard.isFlashUnusable = function () {
        return !!(flashState.disabled || flashState.outdated || flashState.deactivated);
    };
    ZeroClipboard.config = function (options) {
        if (typeof options === "object" && options !== null) {
            _extend(_globalConfig, options);
        }
        if (typeof options === "string" && options) {
            if (_globalConfig.hasOwnProperty(options)) {
                return _globalConfig[options];
            }
            return;
        }
        var copy = {};
        for (var prop in _globalConfig) {
            if (_globalConfig.hasOwnProperty(prop)) {
                if (typeof _globalConfig[prop] === "object" && _globalConfig[prop] !== null) {
                    if ("length" in _globalConfig[prop]) {
                        copy[prop] = _globalConfig[prop].slice(0);
                    } else {
                        copy[prop] = _extend({}, _globalConfig[prop]);
                    }
                } else {
                    copy[prop] = _globalConfig[prop];
                }
            }
        }
        return copy;
    };
    ZeroClipboard.destroy = function () {
        ZeroClipboard.deactivate();
        for (var clientId in _clientMeta) {
            if (_clientMeta.hasOwnProperty(clientId) && _clientMeta[clientId]) {
                var client = _clientMeta[clientId].instance;
                if (client && typeof client.destroy === "function") {
                    client.destroy();
                }
            }
        }
        var flashBridge = flashState.bridge;
        if (flashBridge) {
            var htmlBridge = _getHtmlBridge(flashBridge);
            if (htmlBridge) {
                if (flashState.pluginType === "activex" && "readyState" in flashBridge) {
                    flashBridge.style.display = "none";
                    (function removeSwfFromIE() {
                        if (flashBridge.readyState === 4) {
                            for (var prop in flashBridge) {
                                if (typeof flashBridge[prop] === "function") {
                                    flashBridge[prop] = null;
                                }
                            }
                            flashBridge.parentNode.removeChild(flashBridge);
                            if (htmlBridge.parentNode) {
                                htmlBridge.parentNode.removeChild(htmlBridge);
                            }
                        } else {
                            setTimeout(removeSwfFromIE, 10);
                        }
                    })();
                } else {
                    flashBridge.parentNode.removeChild(flashBridge);
                    if (htmlBridge.parentNode) {
                        htmlBridge.parentNode.removeChild(htmlBridge);
                    }
                }
            }
            flashState.ready = null;
            flashState.bridge = null;
            flashState.deactivated = null;
        }
    };
    ZeroClipboard.activate = function (element) {
        if (currentElement) {
            _removeClass(currentElement, _globalConfig.hoverClass);
            _removeClass(currentElement, _globalConfig.activeClass);
        }
        currentElement = element;
        _addClass(element, _globalConfig.hoverClass);
        _reposition();
        var newTitle = _globalConfig.title || element.getAttribute("title");
        if (newTitle) {
            var htmlBridge = _getHtmlBridge(flashState.bridge);
            if (htmlBridge) {
                htmlBridge.setAttribute("title", newTitle);
            }
        }
        var useHandCursor = _globalConfig.forceHandCursor === true || _getStyle(element, "cursor") === "pointer";
        _setHandCursor(useHandCursor);
    };
    ZeroClipboard.deactivate = function () {
        var htmlBridge = _getHtmlBridge(flashState.bridge);
        if (htmlBridge) {
            htmlBridge.style.left = "0px";
            htmlBridge.style.top = "-9999px";
            htmlBridge.removeAttribute("title");
        }
        if (currentElement) {
            _removeClass(currentElement, _globalConfig.hoverClass);
            _removeClass(currentElement, _globalConfig.activeClass);
            currentElement = null;
        }
    };
    var _bridge = function () {
        var flashBridge, len;
        var container = document.getElementById("global-zeroclipboard-html-bridge");
        if (!container) {
            var opts = ZeroClipboard.config();
            opts.jsModuleId = typeof _amdModuleId === "string" && _amdModuleId || typeof _cjsModuleId === "string" && _cjsModuleId || null;
            var allowScriptAccess = _determineScriptAccess(window.location.host, _globalConfig);
            var flashvars = _vars(opts);
            var swfUrl = _globalConfig.swfPath + _cacheBust(_globalConfig.swfPath, _globalConfig);
            container = document.createElement("div");
            container.id = "global-zeroclipboard-html-bridge";
            container.className = "global-zeroclipboard-container";
            container.style.position = "absolute";
            container.style.left = "0px";
            container.style.top = "-9999px";
            container.style.width = "1px";
            container.style.height = "1px";
            container.style.zIndex = "" + _getSafeZIndex(_globalConfig.zIndex);
            var divToBeReplaced = document.createElement("div");
            container.appendChild(divToBeReplaced);
            document.body.appendChild(container);
            var tmpDiv = document.createElement("div");
            var oldIE = flashState.pluginType === "activex";
            tmpDiv.innerHTML = '<object id="global-zeroclipboard-flash-bridge" width="100%" height="100%" ' + (oldIE ? 'classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000"' : 'type="application/x-shockwave-flash" data="' + swfUrl + '"') + ">" + (oldIE ? '<param name="movie" value="' + swfUrl + '"/>' : "") + '<param name="allowScriptAccess" value="' + allowScriptAccess + '"/>' + '<param name="allowFullScreen" value="false"/>' + '<param name="scale" value="exactfit"/>' + '<param name="loop" value="false"/>' + '<param name="menu" value="false"/>' + '<param name="quality" value="best" />' + '<param name="bgcolor" value="#ffffff"/>' + '<param name="wmode" value="transparent"/>' + '<param name="flashvars" value="' + flashvars + '"/>' + "</object>";
            flashBridge = tmpDiv.firstChild;
            tmpDiv = null;
            container.replaceChild(flashBridge, divToBeReplaced);
        }
        if (!flashBridge) {
            flashBridge = document["global-zeroclipboard-flash-bridge"];
            if (flashBridge && (len = flashBridge.length)) {
                flashBridge = flashBridge[len - 1];
            }
            if (!flashBridge) {
                flashBridge = container.firstChild;
            }
        }
        flashState.bridge = flashBridge || null;
    };
    var _getHtmlBridge = function (flashBridge) {
        var htmlBridge = flashBridge && flashBridge.parentNode;
        while (htmlBridge && htmlBridge.nodeName === "OBJECT" && htmlBridge.parentNode) {
            htmlBridge = htmlBridge.parentNode;
        }
        return htmlBridge || null;
    };
    var _reposition = function () {
        if (currentElement) {
            var pos = _getDOMObjectPosition(currentElement, _globalConfig.zIndex);
            var htmlBridge = _getHtmlBridge(flashState.bridge);
            if (htmlBridge) {
                htmlBridge.style.top = pos.top + "px";
                htmlBridge.style.left = pos.left + "px";
                htmlBridge.style.width = pos.width + "px";
                htmlBridge.style.height = pos.height + "px";
                htmlBridge.style.zIndex = pos.zIndex + 1;
            }
            if (flashState.ready === true && flashState.bridge && typeof flashState.bridge.setSize === "function") {
                flashState.bridge.setSize(pos.width, pos.height);
            } else {
                flashState.ready = false;
            }
        }
        return this;
    };
    ZeroClipboard.emit = function (event) {
        var eventType, eventObj;
        if (typeof event === "string" && event) {
            eventType = event;
        }
        if (typeof event === "object" && event && typeof event.type === "string" && event.type) {
            eventType = event.type;
            eventObj = event;
        }
        if (!eventType) {
            return;
        }
        event = _createEvent(eventType, eventObj);
        _preprocessEvent(event);
        if (event.type === "ready" && flashState.overdue === true) {
            return ZeroClipboard.emit({
                type: "error",
                name: "flash-overdue"
            });
        }
        var performCallbackAsync = !/^(before)?copy$/.test(event.type);
        if (event.client) {
            _dispatchClientCallbacks.call(event.client, event, performCallbackAsync);
        } else {
            var clients = event.target && event.target !== window && _globalConfig.autoActivate === true ? _getAllClientsClippedToElement(event.target) : _getAllClients();
            var i, len, eventCopy;
            for (i = 0, len = clients.length; i < len; i++) {
                eventCopy = _extend({}, event, {
                    client: clients[i]
                });
                _dispatchClientCallbacks.call(clients[i], eventCopy, performCallbackAsync);
            }
        }
        return event.type === "copy" ? JSON.stringify(_clipData) : undefined;
    };
    var _dispatchClientCallbacks = function (event, async) {
        var handlers = _clientMeta[this.id] && _clientMeta[this.id].handlers[event.type];
        if (handlers && handlers.length) {
            var i, len, func, context, originalContext = this;
            for (i = 0, len = handlers.length; i < len; i++) {
                func = handlers[i];
                context = originalContext;
                if (typeof func === "string" && typeof window[func] === "function") {
                    func = window[func];
                }
                if (typeof func === "object" && func && typeof func.handleEvent === "function") {
                    context = func;
                    func = func.handleEvent;
                }
                if (typeof func === "function") {
                    _dispatchCallback(func, context, [event], async);
                }
            }
        }
        return this;
    };
    var _eventMessages = {
        ready: "Flash communication is established",
        error: {
            "flash-disabled": "Flash is disabled or not installed",
            "flash-outdated": "Flash is too outdated to support ZeroClipboard",
            "flash-deactivated": "Flash is too outdated for your browser and/or is configured as click-to-activate",
            "flash-overdue": "Flash communication was established but NOT within the acceptable time limit"
        }
    };
    var _createEvent = function (eventType, event) {
        if (!(eventType || event && event.type)) {
            return;
        }
        event = event || {};
        eventType = (eventType || event.type).toLowerCase();
        _extend(event, {
            type: eventType,
            target: event.target || currentElement || null,
            relatedTarget: event.relatedTarget || null,
            currentTarget: flashState && flashState.bridge || null
        });
        var msg = _eventMessages[event.type];
        if (event.type === "error" && event.name && msg) {
            msg = msg[event.name];
        }
        if (msg) {
            event.message = msg;
        }
        if (event.type === "ready") {
            _extend(event, {
                target: null,
                version: flashState.version
            });
        }
        if (event.type === "error") {
            event.target = null;
            if (/^flash-(outdated|deactivated|overdue)$/.test(event.name)) {
                _extend(event, {
                    version: flashState.version,
                    minimumVersion: "11.0.0"
                });
            }
        }
        if (event.type === "copy") {
            event.clipboardData = {
                setData: function (format, data) {
                    if (typeof format === "string" && format && data != null) {
                        _clipData[format] = data;
                    }
                },
                clearData: function (format) {
                    if (_clipData.hasOwnProperty(format)) {
                        delete _clipData[format];
                    }
                }
            };
        }
        if (event.type === "aftercopy" && event.serializedData) {
            var deserializedData = JSON.parse(event.serializedData);
            if (typeof deserializedData === "object" && deserializedData) {
                _extend(event, deserializedData);
            }
            delete event.serializedData;
        }
        if (event.target && !event.relatedTarget) {
            event.relatedTarget = _getRelatedTarget(event.target);
        }
        return event;
    };
    var _getRelatedTarget = function (targetEl) {
        var relatedTargetId = targetEl && targetEl.getAttribute && targetEl.getAttribute("data-clipboard-target");
        return relatedTargetId ? document.getElementById(relatedTargetId) : null;
    };
    var _preprocessEvent = function (event) {
        var element = event.target || currentElement;
        switch (event.type) {
            case "error":
                if (_inArray(event.name, ["flash-disabled", "flash-outdated", "flash-deactivated", "flash-overdue"])) {
                    _extend(flashState, {
                        disabled: event.name === "flash-disabled",
                        outdated: event.name === "flash-outdated",
                        deactivated: event.name === "flash-deactivated",
                        overdue: event.name === "flash-overdue",
                        ready: false
                    });
                }
                break;

            case "ready":
                var wasDeactivated = flashState.deactivated === true;
                _extend(flashState, {
                    disabled: false,
                    outdated: false,
                    deactivated: false,
                    overdue: wasDeactivated,
                    ready: !wasDeactivated
                });
                break;

            case "copy":
                var textContent, targetEl = event.relatedTarget;
                if (targetEl && (textContent = targetEl.value || targetEl.textContent || targetEl.innerText)) {
                    event.clipboardData.setData("text/plain", textContent);
                } else if (event.target && (textContent = event.target.getAttribute("data-clipboard-text"))) {
                    event.clipboardData.setData("text/plain", textContent);
                }
                break;

            case "aftercopy":
                _deleteOwnProperties(_clipData);
                if (element && element !== _safeActiveElement() && element.focus) {
                    element.focus();
                }
                break;

            case "mouseover":
                _addClass(element, _globalConfig.hoverClass);
                break;

            case "mouseout":
                if (_globalConfig.autoActivate === true) {
                    ZeroClipboard.deactivate();
                }
                break;

            case "mousedown":
                _addClass(element, _globalConfig.activeClass);
                break;

            case "mouseup":
                _removeClass(element, _globalConfig.activeClass);
                break;
        }
    };
    ZeroClipboard.prototype.on = function (eventName, func) {
        var i, len, events, added = {}, handlers = _clientMeta[this.id] && _clientMeta[this.id].handlers;
        if (typeof eventName === "string" && eventName) {
            events = eventName.toLowerCase().split(/\s+/);
        } else if (typeof eventName === "object" && eventName && typeof func === "undefined") {
            for (i in eventName) {
                if (eventName.hasOwnProperty(i) && typeof i === "string" && i && typeof eventName[i] === "function") {
                    this.on(i, eventName[i]);
                }
            }
        }
        if (events && events.length) {
            for (i = 0, len = events.length; i < len; i++) {
                eventName = events[i].replace(/^on/, "");
                added[eventName] = true;
                if (!handlers[eventName]) {
                    handlers[eventName] = [];
                }
                handlers[eventName].push(func);
            }
            if (added.ready && flashState.ready) {
                ZeroClipboard.emit({
                    type: "ready",
                    client: this
                });
            }
            if (added.error) {
                if (flashState.disabled) {
                    ZeroClipboard.emit({
                        type: "error",
                        name: "flash-disabled",
                        client: this
                    });
                } else if (flashState.outdated) {
                    ZeroClipboard.emit({
                        type: "error",
                        name: "flash-outdated",
                        client: this
                    });
                } else if (flashState.deactivated) {
                    ZeroClipboard.emit({
                        type: "error",
                        name: "flash-deactivated",
                        client: this
                    });
                } else if (flashState.overdue) {
                    ZeroClipboard.emit({
                        type: "error",
                        name: "flash-overdue",
                        client: this
                    });
                }
            }
        }
        return this;
    };
    ZeroClipboard.prototype.off = function (eventName, func) {
        var i, len, foundIndex, events, perEventHandlers, handlers = _clientMeta[this.id] && _clientMeta[this.id].handlers;
        if (arguments.length === 0) {
            events = _objectKeys(handlers);
        } else if (typeof eventName === "string" && eventName) {
            events = eventName.split(/\s+/);
        } else if (typeof eventName === "object" && eventName && typeof func === "undefined") {
            for (i in eventName) {
                if (eventName.hasOwnProperty(i) && typeof i === "string" && i && typeof eventName[i] === "function") {
                    this.off(i, eventName[i]);
                }
            }
        }
        if (events && events.length) {
            for (i = 0, len = events.length; i < len; i++) {
                eventName = events[i].toLowerCase().replace(/^on/, "");
                perEventHandlers = handlers[eventName];
                if (perEventHandlers && perEventHandlers.length) {
                    if (func) {
                        foundIndex = _inArray(func, perEventHandlers);
                        while (foundIndex !== -1) {
                            perEventHandlers.splice(foundIndex, 1);
                            foundIndex = _inArray(func, perEventHandlers, foundIndex);
                        }
                    } else {
                        handlers[eventName].length = 0;
                    }
                }
            }
        }
        return this;
    };
    ZeroClipboard.prototype.handlers = function (eventName) {
        var prop, copy = null, handlers = _clientMeta[this.id] && _clientMeta[this.id].handlers;
        if (handlers) {
            if (typeof eventName === "string" && eventName) {
                return handlers[eventName] ? handlers[eventName].slice(0) : null;
            }
            copy = {};
            for (prop in handlers) {
                if (handlers.hasOwnProperty(prop) && handlers[prop]) {
                    copy[prop] = handlers[prop].slice(0);
                }
            }
        }
        return copy;
    };
    ZeroClipboard.prototype.clip = function (elements) {
        elements = _prepClip(elements);
        for (var i = 0; i < elements.length; i++) {
            if (elements.hasOwnProperty(i) && elements[i] && elements[i].nodeType === 1) {
                if (!elements[i].zcClippingId) {
                    elements[i].zcClippingId = "zcClippingId_" + elementIdCounter++;
                    _elementMeta[elements[i].zcClippingId] = [this.id];
                    if (_globalConfig.autoActivate === true) {
                        _addEventHandler(elements[i], "mouseover", _elementMouseOver);
                    }
                } else if (_inArray(this.id, _elementMeta[elements[i].zcClippingId]) === -1) {
                    _elementMeta[elements[i].zcClippingId].push(this.id);
                }
                var clippedElements = _clientMeta[this.id].elements;
                if (_inArray(elements[i], clippedElements) === -1) {
                    clippedElements.push(elements[i]);
                }
            }
        }
        return this;
    };
    ZeroClipboard.prototype.unclip = function (elements) {
        var meta = _clientMeta[this.id];
        if (meta) {
            var clippedElements = meta.elements;
            var arrayIndex;
            if (typeof elements === "undefined") {
                elements = clippedElements.slice(0);
            } else {
                elements = _prepClip(elements);
            }
            for (var i = elements.length; i--;) {
                if (elements.hasOwnProperty(i) && elements[i] && elements[i].nodeType === 1) {
                    arrayIndex = 0;
                    while ((arrayIndex = _inArray(elements[i], clippedElements, arrayIndex)) !== -1) {
                        clippedElements.splice(arrayIndex, 1);
                    }
                    var clientIds = _elementMeta[elements[i].zcClippingId];
                    if (clientIds) {
                        arrayIndex = 0;
                        while ((arrayIndex = _inArray(this.id, clientIds, arrayIndex)) !== -1) {
                            clientIds.splice(arrayIndex, 1);
                        }
                        if (clientIds.length === 0) {
                            if (_globalConfig.autoActivate === true) {
                                _removeEventHandler(elements[i], "mouseover", _elementMouseOver);
                            }
                            delete elements[i].zcClippingId;
                        }
                    }
                }
            }
        }
        return this;
    };
    ZeroClipboard.prototype.elements = function () {
        var meta = _clientMeta[this.id];
        return meta && meta.elements ? meta.elements.slice(0) : [];
    };
    var _getAllClientsClippedToElement = function (element) {
        var elementMetaId, clientIds, i, len, client, clients = [];
        if (element && element.nodeType === 1 && (elementMetaId = element.zcClippingId) && _elementMeta.hasOwnProperty(elementMetaId)) {
            clientIds = _elementMeta[elementMetaId];
            if (clientIds && clientIds.length) {
                for (i = 0, len = clientIds.length; i < len; i++) {
                    client = _clientMeta[clientIds[i]].instance;
                    if (client && client instanceof ZeroClipboard) {
                        clients.push(client);
                    }
                }
            }
        }
        return clients;
    };
    _globalConfig.hoverClass = "zeroclipboard-is-hover";
    _globalConfig.activeClass = "zeroclipboard-is-active";
    if (typeof define === "function" && define.amd) {
        define(["require", "exports", "module"], function (require, exports, module) {
            _amdModuleId = module && module.id || null;
            return ZeroClipboard;
        });
    } else if (typeof module === "object" && module && typeof module.exports === "object" && module.exports && typeof window.require === "function") {
        _cjsModuleId = module.id || null;
        module.exports = ZeroClipboard;
    } else {
        window.ZeroClipboard = ZeroClipboard;
    }
})(function () {
    return this;
}());