/// <reference path="gMapFunctions.js" />
/// <reference path="../map/radarSites.js" />
/// <reference path="~/vsdocs/google-maps-3-vs-1-0-vsdoc.js" />
$(function () {
    $('#ahCredentialsForm').submit(function (event) {
        event.preventDefault();
        $.ajax({
            type: 'POST',
            url: 'https://access.allisonhouse.com/hazwx/login.php',
            data: $(this).serialize(),
            dataType: 'text',
            async: false,
            success: function (data) {
                if (data == "NO") {
                    alert("It appears that AllisonHouse disagrees. Check your username and password, try again.");
                    return false;
                }
                var pTokenStartPosition = data.indexOf('P: ');
                if (pTokenStartPosition < 0) {
                    alert("You don't appear to have the required service on your AllisonHouse account.")
                    return false;
                }
                hideElement('ahCredForm');
                var pToken = data.substring(pTokenStartPosition + 3, data.length);
                allisonHousePToken = pToken; //save in global variable
                sendAHToken(); //send token to HN API to save in user's AH account
            }
        }).fail(function (data) {
            alert("Could not connect to AllisonHouse to verify. Check your connection. If this problem continues please report it.");
            return false;
        });
    });
});

function getAHToken(button, downloadCallback) {
    console.log("Checking for AllisonHouse token in variable initialized from cookie");
    if (allisonHousePToken) {                     //token was in the cookie, use it.
        console.log("Token found in cookie");
        return downloadCallback();
    }

    else {         //no token in cookie, ask Robert for the token.
        console.log("Wasn't in variable, so asking HN API for stored AH token...");
        var url = "http://api.hazardnotifications.com/get_ah_token/";

        $.getJSON(url, { user_id: wordpressUserIdNumber, user_pass: wordpressUserHash }, function (data) {

            console.log("HN API call success: " + data.success);

            if (data.success != true) {             //API returned false, find out why
                if (data.reason == "No tokens found.") {
                    console.log("Asking user to submit AH credentials to retrieve token...");
                    document.getElementById("ahCredForm").style.display = "block";
                }
                else {
                    alert("We could not retrieve your AllisonHouse account information. Make sure you are logged in.");
                }
                $(button).prop("checked", false);
                $(button).button("refresh");
                return false;
            }

            else {  //data.success was true, API has the token!
                console.log("HN API returned token: " + data.tokens.P);     //correctly shows token
                if (allisonHousePToken == "undefined") {
                    document.getElementById("ahCredForm").style.display = "block";
                    return false;
                }
                allisonHousePToken = data.tokens.P;
                downloadCallback();
            }
        });
    }
}

function sendAHToken() {
    //send token to HN API
    var theUrl = "http://api.hazardnotifications.com/set_ah_token/?user_id=" + wordpressUserIdNumber +
        "&user_pass=" + wordpressUserHash + "&token_type=P&token=" + allisonHousePToken;
    console.log("Sending AllisonHouse token: " + theUrl);
    var xmlHttp = new XMLHttpRequest();
    xmlHttp.open("GET", theUrl, false);
    xmlHttp.send(null);
    console.log("Update token resulted in " + xmlHttp.responseText);
    return xmlHttp.responseText;
}

function checkReportDownloadTime(report, button, lastDownloadTime, toggleCallback, downloadCallback) {
    if (wordpressUserIdNumber == 0) {
        $(button).prop("checked", false);
        $(button).button("refresh");
        var loginNow = confirm("You need to login to use this feature. Click OK to log in now.");
        if (loginNow) {
            goToPanel(0);
        }
        return;
    }

    var rightNow = new Date();
    toggleCallback(report);
    if (rightNow - lastDownloadTime > 900000) {   //if ahDownloadTime was more than 15 minutes ago
        getAHToken(button, downloadCallback);
    }
}

function getSiteNamesFromBounds(latLngBounds) {
    var siteNames = [];
    for (var site in radarSites) {
        if (latLngBounds.contains(new google.maps.LatLng(radarSites[site].lat, radarSites[site].lng)))
            siteNames.push(site);
    }
    return siteNames;
}

function getClosestSiteToCenter(latLng, sites) {
    var siteNames = [];
    for (var i = 0; i < sites.length; i++) {
        siteNames.push({name: sites[i], distance:google.maps.geometry.spherical.computeDistanceBetween(latLng, new google.maps.LatLng(radarSites[sites[i]].lat, radarSites[sites[i]].lat))});
    }
    var closestSite = siteNames[0].name;
    for (i = 0; i < siteNames.length - 1; i++) {
        if (siteNames[i].distance > siteNames[i + 1])
            closestSite = siteNames[i + 1].name;
    }
    return closestSite;
}

function rotateSymbol(x, y, xm, ym, a) {
    var cos = Math.cos,
        sin = Math.sin,
        r = a * Math.PI / 180, // Convert to radians because that's what
                               // JavaScript likes
        // Subtract midpoints, so that midpoint is translated to origin
        // and add it in the end again
        xr = (x - xm) * cos(r) - (y - ym) * sin(r) + xm,
        yr = (x - xm) * sin(r) + (y - ym) * cos(r) + ym;

    return [xr.toFixed(5), yr.toFixed(5)];
}