/// <reference path="~/vsdocs/google-maps-3-vs-1-0.js" />
/// <reference path="gMapFunctions.js" />
/// <reference path="ahCore.js" />
/// <reference path="../map/radarSites.js" />

var ahMcdDownloadTime = new Date(0);
//create AllisonHouse Storm Report object (arrays will be stored within as properties)
var ahMcds = [];
var mcdBoxColors = { 'SEVERE POTENTIAL...WATCH UNLIKELY': 'brown', 'SEVERE POTENTIAL...WATCH POSSIBLE': 'red', 'SEVERE POTENTIAL...WATCH LIKELY': '#FF0000', 'SEVERE THUNDERSTORM WATCH 38...39...': 'red', 'SEVERE POTENTIAL...TORNADO WATCH LIKELY': 'red', 'WINTER MIXED PRECIPITATION': 'pink', 'FREEZING RAIN': 'pink', 'HEAVY SNOW': 'blue' };
var requestedMcd = null;

$(function() {
    $("#mesoToggle").change(function() {
        checkReportDownloadTime(this.id, $(this), ahMcdDownloadTime, toggleMcds, downloadAHMcd);
    });
});


function downloadAHMcd() {
    waitForIt();
    console.log("Starting fetch of AH Reports...");
    ahMcdDownloadTime = new Date(); //record our time
    var reportCounter = 0;
    ahMcds = []; //array for all the storm report markers
    //var phenoms = Object.keys(ahPhenoms[requestedMcd]).map(function (c) { return "phenom[]=" + c; }).join('&');

    for (var siteName in radarSites) {
        var url = "http://feeds.allisonhouse.com/" + allisonHousePToken + "/Mcd.json?site=" + siteName;

        $.getJSON(url, function(data) {
            for (var a in data.discussions) {
                var mcd = data.discussions[a];
                var mcdRaw = mcd.raw;
                var concerningStart = mcdRaw.indexOf("\nCONCERNING...") + 14;
                var concerningEnd = mcdRaw.indexOf("\n", concerningStart);
                var concerning = mcdRaw.substr(concerningStart, concerningEnd - concerningStart).trim();
                var polygon = new google.maps.Polygon({
                    paths: mcd.outline
                        .split('\n').map(function(c) {
                            return new google.maps.LatLng(c.split(',')[0], c.split(',')[1]);
                        }),
                    strokeColor: mcdBoxColors[concerning],
                    strokeOpacity: 1,
                    strokeWeight: 2,
                    fillColor: mcdBoxColors[concerning],
                    fillOpacity: 0.0,
                    title: "Event: " + mcd.type +
                        "\nExpire Time (UTC): " + mcd.expire +
                        "\nConcerning: " + concerning
                });

                //add phenom to that marker
                google.maps.event.addListener(polygon, 'click', function(e) {
                    infoWindow.setContent("<div id='infoWindowContent'><b>" +
                        this.title.replace(/\n/g, '<BR><B>').replace(/:/g, ':</B>') +
                        //"<B>Event: " + mcd.phenom + "</B><BR>" +
                        //"<B>Time:</B> " + mcd.timestamp + " (UTC)<BR>" +
                        //"<B>Magnitude:</B> " + mcd.mag + "<BR>" +
                        //"<B>City:</B> " + mcd.city + ", " + mcd.state + "<BR>" +
                        //"<B>County:</B> " + mcd.county + "<BR>" +
                        //"<B>Source:</B> " + mcd.source + "<BR>" +
                        //"<B>Remarks:</B> " + mcd.remarks + "<BR>" +
                        "</div>");
                    infoWindow.setPosition(e.latLng);
                    infoWindow.open(map);
                });
                mcd.polygon = polygon;
                ahMcds.push(polygon);
                //for (var category in ahPhenoms) {
                //    if (ahPhenoms[category].hasOwnProperty(mcd.phenom)) {
                //        ahMcds[category].push(polygon);
                //        break;
                //    }
                //}
                //console.log(mcd.phenom); //show what just got pushed
            }
        }).done(function() {
            //console.log("getJSON complete for " + radarSiteNames[reportCounter]);
            reportCounter++;
            if (reportCounter == Object.keys(radarSites).length) {
                doneWaiting();
                console.log("all finished, " + reportCounter + " sites loaded. Took " + (new Date() - ahMcdDownloadTime) / 1000 + " secs");
                toggleMcds(requestedMcd);
            }
        });
    }
}

function toggleMcds() {
    if (!ahMcds || !ahMcds[0]) return;
    if (ahMcds[0].getMap() == map) { //markers already visible, remove them
        for (var i = 0; i < ahMcds.length; i++) {
            ahMcds[i].setMap(null); //remove marker
            $("#preloadImagesBtn").prop("checked", false);
        }
    } else { //remove the map
        for (i = 0; i < ahMcds.length; i++) {
            ahMcds[i].setMap(map); //place marker on map
            $("#preloadImagesBtn").prop("checked", true);
        }
    }
}