/// <reference path="~/vsdocs/google-maps-3-vs-1-0.js" />
/// <reference path="gMapFunctions.js" />
/// <reference path="ahCore.js" />
/// <reference path="../map/radarSites.js" />
/// <reference path="~/scr/markerwithlabel.js" />
/// <reference path="~/scr/markerclusterer.js" />
var ahMesonetDownloadTime = new Date(0);
//create AllisonHouse Storm Report object (arrays will be stored within as properties)
var ahMesonets = [];
var mesonetIconImages;
var markerClusterer;

$(function () {
    $("#mesonetToggle").change(function (e) {
        checkReportDownloadTime(this.id, $(this), ahMesonetDownloadTime, toggleMesonet, downloadAHMesonet);
    });
});



function downloadAHMesonet() {
    if (map.getZoom() < 8) {
        alert('You need to zoom in to use this');
        return;
    }
    waitForIt();
    console.log("Starting fetch of AH Reports...");
    ahMesonetDownloadTime = new Date(); //record our time
    var reportCounter = 0;
    ahMesonets = [];
    if (!mesonetIconImages) {
        mesonetIconImages = ["M1,3 3,3 3,20 1,20 z",
        "M1,3 3,3 3,7 6,6 6,8 3,9 3,20 1,20 z",
        "M1,3 10,2 10,4 3,5 3,20 1,20 z",
        "M1,3 10,2 10,4 3,5 3,7 6,6 6,8 3,9 3,20 1,20 z",
        "M1,3 10,2 10,4 3,5 3,7 10,6 10,8 3,9 3,20 1,20 z",
        "M1,3 10,2 10,4 3,5 3,7 10,6 10,8 3,9 3,11 6,10 6,12 3,13 3,20 1,20 z",
        "M1,3 10,2 10,4 3,5 3,7 10,6 10,8 3,9 3,11 10,10 10,12 3,13 3,20 1,20 z" ];
    }
    var siteNames = getSiteNamesFromBounds(map.getBounds());
    siteNames = [getClosestSiteToCenter(map.getCenter(), siteNames)];
    for (var i = 0; i < siteNames.length; i++) {
        var url = "http://feeds.allisonhouse.com/" + allisonHousePToken + "/Mesonet.json?site=" + siteNames[i];
        $.getJSON(url, function (data) {
            for (var o = 0; o < data.obs.length; o++) {
                var obs = data.obs[o];
                if(!obs.wind_dir || !obs.temp_c || !obs.rel_humidity) continue;
                var imageIndex = obs['wind_speed_ms'] / 5;
                var anchor = rotate(1, 28, 5, 23, obs['wind_dir']);
                var xAnchor = anchor[0];
                var yAnchor = anchor[1];
                var obsTemp = Math.floor(obs.temp_c * 1.8) + 32;
                var marker = new MarkerWithLabel({
                //var marker = new google.maps.Marker({
                    position: new google.maps.LatLng(obs.lat, obs.lon),
                    map: null,
                    icon: {
                        path: mesonetIconImages[Math.floor(imageIndex)],
                        anchor: new google.maps.Point(xAnchor, yAnchor),
                        scale: 1.4,
                        fillColor: 'white',
                        fillOpacity: 1.0,
                        strokeColor: 'black',
                        strokeWeight: .6,
                        rotation: obs['wind_dir']
                    },
                    title: String.format('{0} @ {1}\n' +
                        '{2}\n'+
                        ' Temp: {3} (Dew: {4})\n'+
                        '  Hum: {5}%\n'+
                        ' Wind: {6}&deg; @ {7} G\n{8} {9} \n{10},{11}', obs.mesonet, obs.obs_time, obs.stnm, obsTemp,
                        obs.dew_f, obs.rel_humidity, obs['wind_dir'], obs['wind_speed_ms']
                        , xAnchor, yAnchor, obs.lat, obs.lon),
                    labelContent: String.format('<span class="surfaceTemp">{0}</span><br/><span class="surfaceDew">{1}</span><span class="cloud symbol{2}"><div></div></span>',
                        //'<span class="wind barb{3}"><div></div></span>',
                        obsTemp, obs.dew_f, obs.clouds && obs.clouds['1'] && obs.clouds['1'].number),// Math.floor(imageIndex)),
                    labelAnchor: new google.maps.Point(25,0),
                    labelClass: 'markerLabel minZoom7',
                    labelStyle: { opacity: 1}
                });
                if (imageIndex > mesonetIconImages.length)
                    console.log('wind too strong - ' + imageIndex);

                //add event to that marker
                google.maps.event.addListener(marker, 'click', function(e) {
                    infoWindow.setContent("<div id='infoWindowContent'><b>" +
                        this.title.replace(/\n/g, '<BR><B>').replace(/:/g, ':</B>') +
                        //"<B>Event: " + mesonet.event + "</B><BR>" +
                        //"<B>Time:</B> " + mesonet.timestamp + " (UTC)<BR>" +
                        //"<B>Magnitude:</B> " + mesonet.mag + "<BR>" +
                        //"<B>City:</B> " + mesonet.city + ", " + mesonet.state + "<BR>" +
                        //"<B>County:</B> " + mesonet.county + "<BR>" +
                        //"<B>Source:</B> " + mesonet.source + "<BR>" +
                        //"<B>Remarks:</B> " + mesonet.remarks + "<BR>" +
                        "</div>");
                    infoWindow.setPosition(e.latLng);
                    infoWindow.open(map);
                });
                ahMesonets.push(marker);

                //console.log(mesonet); //show what just got pushed
            }
        }).done(function (e) {
            //console.log("getJSON complete for " + radarSiteNames[reportCounter]); //the radarSiteNames[i] is undefined.
            reportCounter++;
            if (reportCounter == siteNames.length) {
                doneWaiting();
                console.log("all finished, " + reportCounter + " sites loaded.");
                //markerClusterer = new MarkerClusterer(map, ahMesonets, { gridSize: 30, maxZoom: 8 });
                toggleMesonet();
            }
        });
    }
}

function toggleMesonet() {
    if (!ahMesonets[0]) return;
    //if (markerClusterer.getMarkers().length > 0) {   //markers already visible, remove them
        //markerClusterer.clearMarkers();
    //return;
    if(ahMesonets[0].getMap() == map){
        for (var i = 0; i < ahMesonets.length; i++) {
            ahMesonets[i].setMap(null);   //remove marker
            $("#preloadImagesBtn").prop("checked", false);
        }
    }
    else {  
        //markerClusterer.addMarkers(ahMesonets);
        //return;
        for (i = 0; i < ahMesonets.length; i++) {
            ahMesonets[i].setMap(map);   //place marker on map
            $("#preloadImagesBtn").prop("checked", true);
        }
    }
}
