/// <reference path="~/vsdocs/google-maps-3-vs-1-0.js" />
/// <reference path="gMapFunctions.js" />
/// <reference path="ahCore.js" />
/// <reference path="../map/radarSites.js" />
/// <reference path="~/scr/markerwithlabel.js" />
/// <reference path="~/scr/markerclusterer.js" />
var ahMetarDownloadTime = new Date(0);
//create AllisonHouse Storm Report object (arrays will be stored within as properties)
var ahMetars = [];
var metarIconImages;
var markerClusterer;

$(function () {
    $("#surfObsToggle").change(function (e) {
        checkReportDownloadTime(this.id, $(this), ahMetarDownloadTime, toggleMetar, downloadAHMetar);
    });
});



function downloadAHMetar() {
    if (map.getZoom() < 7) {
        alert('You need to zoom in to use this');
        return;
    }
    waitForIt();
    console.log("Starting fetch of AH Reports...");
    ahMetarDownloadTime = new Date(); //record our time
    var reportCounter = 0;
    ahMetars = [];
    if (!metarIconImages) {
        metarIconImages = ["M 1,3 3,3 3,20 1,20 z",
        "M 1,3 3,3 3,7 6,6 6,8 3,9 3,20 1,20 z",
        "M 1,3 10,2 10,4 3,5 3,20 1,20 z",
        "M 1,3 10,2 10,4 3,5 3,7 6,6 6,8 3,9 3,20 1,20 z",
        "M 1,3 10,2 10,4 3,5 3,7 10,6 10,8 3,9 3,20 1,20 z",
        "M 1,3 10,2 10,4 3,5 3,7 10,6 10,8 3,9 3,11 6,10 6,12 3,13 3,20 1,20 z",
        "M 1,3 10,2 10,4 3,5 3,7 10,6 10,8 3,9 3,11 10,10 10,12 3,13 3,20 1,20 z" ];
    }
    var siteNames = getSiteNamesFromBounds(map.getBounds());
    siteNames = [getClosestSiteToCenter(map.getCenter(), siteNames)];
    for (var i = 0; i < siteNames.length; i++) {
        var url = "http://feeds.allisonhouse.com/" + allisonHousePToken + "/Metar.json?site=" + siteNames[i];
        var a = -1;
        $.getJSON(url, function (data) {
            for (var ob in data.obs) {
                a++;
                var obs = data.obs[ob];
                if(!obs.contents.temperature || !obs.contents.altimeter || !obs.contents.visibility) continue;
                var icao = obs.icaos[ob];
                var wind = obs.contents.wind;
                var imageIndex = wind.knots / 5;
                var anchor = rotateSymbol(1, 28, 1, 18, wind.deg);
                var xAnchor = anchor[0];
                var yAnchor = anchor[1];
                var marker = new MarkerWithLabel({
                //var marker = new google.maps.Marker({
                    position: new google.maps.LatLng(39.267 + (a/6)*2,-103.667 + (a%6)*2),//(icao.lat, icao.lon),
                    map: null,
                    icon: {
                        path: metarIconImages[Math.floor(imageIndex)],
                        anchor: new google.maps.Point(xAnchor, yAnchor),
                        scale: 1.4,
                        fillColor: 'white',
                        fillOpacity: 1.0,
                        strokeColor: 'black',
                        strokeWeight: .6,
                        rotation: wind.deg
                    },
                    title: String.format('{0} @ {1}\n' +
                        '{2}\n'+
                        ' Temp: {3} F (Dew: {4})\n'+
                        '  Hum: {5}%\n'+
                        ' Chill: {6} F\n'+
                        '  Sky: {7}\n'+
                        '  Vis: {8} SM\n'+
                        ' Pres: {9} inhg\n'+
                        '  SLP: {10} inhg\n' +
                        ' Wind: {11} @ {12} G {13} mph \n{14} {15} {16}\n{17},{18}', ob, obs.obs_time, icao.place, obs.contents.temperature.temp_f,
                        obs.contents.temperature.dew_f, obs.contents.rel_humidity, obs.contents.windchill_f, obs.contents.clouds['1'] && obs.contents.clouds['1'].condition,
                        obs.contents.visibility.miles, obs.contents.altimeter.inhg, obs.contents.altimeter.inhg, wind.dir, wind.knots, wind.miles_per_hour
                        , wind.deg, xAnchor, yAnchor, icao.lat, icao.lon),
                    labelContent: String.format('<span class="surfaceTemp">{0}</span><br/><span class="surfaceDew">{1}</span><span class="cloud symbol{2}"><div></div></span>', obs.contents.temperature.temp_f, obs.contents.temperature.dew_f, obs.contents.clouds['1'] && obs.contents.clouds['1'].number),
                    labelAnchor: new google.maps.Point(25,0),
                    labelClass: 'markerLabel minZoom7',
                    labelStyle: { opacity: 1}
                });
                if (imageIndex > metarIconImages.length)
                    console.log('wind too strong - ' + imageIndex);

                //add event to that marker
                google.maps.event.addListener(marker, 'click', function(e) {
                    infoWindow.setContent("<div id='infoWindowContent'><b>" +
                        this.title.replace(/\n/g, '<BR><B>').replace(/:/g, ':</B>') +
                        //"<B>Event: " + metar.event + "</B><BR>" +
                        //"<B>Time:</B> " + metar.timestamp + " (UTC)<BR>" +
                        //"<B>Magnitude:</B> " + metar.mag + "<BR>" +
                        //"<B>City:</B> " + metar.city + ", " + metar.state + "<BR>" +
                        //"<B>County:</B> " + metar.county + "<BR>" +
                        //"<B>Source:</B> " + metar.source + "<BR>" +
                        //"<B>Remarks:</B> " + metar.remarks + "<BR>" +
                        "</div>");
                    infoWindow.setPosition(e.latLng);
                    infoWindow.open(map);
                });
                ahMetars.push(marker);

                //console.log(metar); //show what just got pushed
            }
        }).done(function (e) {
            //console.log("getJSON complete for " + radarSiteNames[reportCounter]); //the radarSiteNames[i] is undefined.
            reportCounter++;
            if (reportCounter == siteNames.length) {
                doneWaiting();
                console.log("all finished, " + reportCounter + " sites loaded.");
                //markerClusterer = new MarkerClusterer(map, ahMetars, { gridSize: 30, maxZoom: 8 });
                toggleMetar();
            }
        });
    }
}

function toggleMetar() {
    if (!ahMetars[0]) return;
    //if (markerClusterer.getMarkers().length > 0) {   //markers already visible, remove them
        //markerClusterer.clearMarkers();
    //return;
    if(ahMetars[0].getMap() == map){
        for (var i = 0; i < ahMetars.length; i++) {
            ahMetars[i].setMap(null);   //remove marker
            $("#preloadImagesBtn").prop("checked", false);
        }
        ahMetarDownloadTime = new Date(0);
        ahMetars = [];
    }
    else {  
        //markerClusterer.addMarkers(ahMetars);
        //return;
        for (i = 0; i < ahMetars.length; i++) {
            ahMetars[i].setMap(map);   //place marker on map
            $("#preloadImagesBtn").prop("checked", true);
        }
    }
}
