/// <reference path="~/vsdocs/google-maps-3-vs-1-0.js" />
/// <reference path="gMapFunctions.js" />
/// <reference path="ahCore.js" />
/// <reference path="../map/radarSites.js" />

var ahStormReportDownloadTime = new Date(0);
//create AllisonHouse Storm Report object (arrays will be stored within as properties)
var ahStormReports = {};
var requestedStormReport = null;

$(function () {
    $(".ahStormToggle").change(function (e) {
        checkReportDownloadTime(this.getAttribute("data-reporttype"), $(this), ahStormReportDownloadTime, toggleStormReports, downloadAHReports);
        requestedStormReport = this.getAttribute("data-reporttype");
    });
});



function downloadAHReports() {
    waitForIt();
    console.log("Starting fetch of AH Reports...");
    ahStormReportDownloadTime = new Date(); //record our time
    var reportCounter = 0;
    ahStormReports = { TORNADO: [], HAIL: [], WIND: [], FLOOD: [], WINTER: [], TEMP: [], OTHER: [], MARINE: [] }; //array for all the storm report markers

    for (var siteName in radarSites) {

        var url = "http://feeds.allisonhouse.com/" + allisonHousePToken + "/Reports.json?site=" + siteName;

        $.getJSON(url, function (data) {
            for (var report in data.reports) {
                var stormReport = data.reports[report];
                var marker = new google.maps.Marker({
                    position: new google.maps.LatLng(stormReport.lat, stormReport.lon),
                    map: null,
                    icon: "/img/icons/" + stormReport.event + ".png",
                    title: "Event: " + stormReport.event +
                    "\nTime (UTC): " + stormReport.timestamp +
                    "\nMagnitude: " + stormReport.mag +
                    "\nCity: " + stormReport.city +
                    ", " + stormReport.state +
                    "\nCounty: " + stormReport.county +
                    "\nSource: " + stormReport.source +
                    "\nRemarks: " + stormReport.remarks
                });

                //add event to that marker
                google.maps.event.addListener(marker, 'click', function (e) {
                    infoWindow.setContent("<div id='infoWindowContent'><b>" +
                        this.title.replace(/\n/g, '<BR><B>').replace(/:/g, ':</B>') +
                            //"<B>Event: " + stormReport.event + "</B><BR>" +
                            //"<B>Time:</B> " + stormReport.timestamp + " (UTC)<BR>" +
                            //"<B>Magnitude:</B> " + stormReport.mag + "<BR>" +
                            //"<B>City:</B> " + stormReport.city + ", " + stormReport.state + "<BR>" +
                            //"<B>County:</B> " + stormReport.county + "<BR>" +
                            //"<B>Source:</B> " + stormReport.source + "<BR>" +
                            //"<B>Remarks:</B> " + stormReport.remarks + "<BR>" +
                            "</div>");
                    infoWindow.setPosition(e.latLng);
                    infoWindow.open(map);
                });

                switch (stormReport.event) {
                    case "TORNADO":
                    case "FUNNEL CLOUD":
                        ahStormReports.TORNADO.push(marker);
                        break;

                    case "HAIL":
                        ahStormReports.HAIL.push(marker);
                        break;

                    case "TSTM WND GST":
                    case "HIGH SUST WNDS":
                    case "TSTM WND DMG":
                    case "MICROBURST":
                    case "DOWNBURST":
                    case "NON-TSTM WND GS":
                        ahStormReports.WIND.push(marker);
                        break;

                    case "FLASH FLOOD":
                    case "FLOODING":
                    case "HEAVY RAIN":
                        ahStormReports.FLOOD.push(marker);
                        break;

                    case "SLEET":
                    case "ICE STORM":
                    case "SNOW":
                    case "BLIZZARD":
                    case "HEAVY SNOW":
                        ahStormReports.WINTER.push(marker);
                        break;

                    case "EXCESSIVE HEAT":
                    case "EXTREME COLD":
                    case "EXTR WIND CHILL":
                    case "FREEZE":
                        ahStormReports.TEMP.push(marker);
                        break;

                    case "SEICHE":
                    case "MARINE WINDS":
                    case "HIGH SURF":
                    case "STORM SURGE":
                    case "RIP CURRENTS":
                    case "TROPICAL STORM":
                    case "HURRICANE":
                    case "WATER SPOUT":
                        ahStormReports.MARINE.push(marker);
                        break;

                    default:
                        ahStormReports.OTHER.push(marker);
                }

                //console.log(stormReport); //show what just got pushed
            }
        }).done(function (e) {
            //console.log("getJSON complete for " + radarSiteNames[reportCounter]); //the radarSiteNames[i] is undefined.
            reportCounter++;
            if (reportCounter == Object.keys(radarSites).length) {
                doneWaiting();
                console.log("all finished, " + reportCounter + " sites loaded.");
                toggleStormReports(requestedStormReport);
            }
        });
    }
}

function toggleStormReports(reportType) {
    if (!ahStormReports || !ahStormReports[reportType] || !ahStormReports[reportType][0]) return;
    if (ahStormReports[reportType][0].getMap() == map) {   //markers already visible, remove them
        for (var i = 0; i < ahStormReports[reportType].length; i++) {
            ahStormReports[reportType][i].setMap(null);   //remove marker
            $("#preloadImagesBtn").prop("checked", false);
        }
    }
    else {  //remove the map
        for (i = 0; i < ahStormReports[reportType].length; i++) {
            ahStormReports[reportType][i].setMap(map);   //place marker on map
            $("#preloadImagesBtn").prop("checked", true);
        }
    }
}
