/// <reference path="~/vsdocs/google-maps-3-vs-1-0.js" />
/// <reference path="gMapFunctions.js" />
/// <reference path="ahCore.js" />
/// <reference path="../map/radarSites.js" />

var ahSpcOutlookDownloadTime = new Date(0);
//create AllisonHouse Storm Report object (arrays will be stored within as properties)
var ahSpcOutlooks = { Day1: { borderColor: '#000', outlooks: new Array(5) }, Day2: { borderColor: '#000', outlooks: new Array(5) } };
var spcBoxColors = [
{},
{Name: 'Tornado', '0.02': 'green', '0.05': '#8B4726', '0.10': 'yellow', '0.15': 'red', '0.30': 'pink', '0.45': 'purple', '0.60': 'blue', Sig: 'black' },
{Name: 'Hail', '0.05': '#8B4726', '0.10': 'yellow', '0.30': 'red', '0.45': 'pink', '0.60': 'purple', Sig: 'black' },
{Name: 'Wind', '0.05': '#8B4726', '0.15': 'yellow', '0.30': 'red', '0.45': 'pink', '0.60': 'purple', Sig: 'black' },
{Name: 'Categorical', TSTM: '#82D282', SLGT: '#FFC000', MDT: '#FF0000', HIGH: '#FF00FF'},
{ Name: 'Probabilistic', '0.05': '#8B4726', '0.15': 'yellow', '0.30': 'red', '0.45': 'pink', '0.60': 'purple', SIGN: 'black' }];
var requestedSpcOutlook = null;

$(function () {
    $(".ah2Toggle").change(function () {
        requestedSpcOutlook = this.getAttribute("data-reporttype");
        checkReportDownloadTime(this.getAttribute("data-reporttype"), $(this), ahSpcOutlookDownloadTime, toggleSpcOutlooks, downloadAHSpcOutlook);
    });
});



function downloadAHSpcOutlook() {
    waitForIt();
    console.log("Starting fetch of AH Reports...");
    ahSpcOutlookDownloadTime = new Date(); //record our time
    ahSpcOutlooks = { Day1: { borderColor: '#000', outlooks: new Array(5) }, Day2: { borderColor: '#fff', outlooks: new Array(5) } }; //array for all the storm report markers
    for (var outlookType in ahSpcOutlooks) {
        var url = "http://feeds.allisonhouse.com/" + allisonHousePToken + "/" + outlookType + ".json";

        $.ajax({
            url: url,
            async: false,
            dataType: "JSON",
            success: function(data) {
                if (!data.outlooks || data.outlooks.length == 0) return;
                for (var a = 0; a < data.outlooks.length; a++) {
                    var spcOutlook = data.outlooks[a];
                    var boxColorName = spcOutlook.prob;//.replace('0.', '').replace('0', 'zero').replace('1', 'one').replace('3', 'three').replace('4', 'four').replace('6', 'six');
                    if (!(boxColorName in spcBoxColors[spcOutlook.type])) continue;
                    var shapes = spcOutlook.line.replace('\r\r','').split('99999999');
                    for (var b = 0; b < shapes.length; b++) {
                        var lines = shapes[b].split(' ').map(function(c) {
                            var lat = parseInt(c.substr(0, 4)) * .01;
                            var lng = parseInt(c.substr(4)) * (-.01);
                            lng = lng > -65 ? -100 + lng : lng;
                            if (lat != 99.99)
                                return [lat, lng];
                        });
                        var titlePrefix = spcOutlook.type == 4 ? 'Category: ' : 'Risk: ';
                        var title = ['4', '6'].indexOf(spcOutlook.type) == -1 ? Math.floor(parseFloat(spcOutlook.prob) * 100) + '%' + spcBoxColors[spcOutlook.type].Name : spcOutlook.prob;
                        var paths = lines.map(function(c) {
                            return new google.maps.LatLng(c[0], c[1]);
                        });
                        var color = spcBoxColors[spcOutlook.type][boxColorName];
                        var polygon = new google.maps.Polygon({
                            paths: paths,
                            strokeColor: color,
                            strokeOpacity: 0,
                            strokeWeight: 5,
                            fillColor: color,
                            fillOpacity: .1,
                            zIndex: parseInt(spcOutlook.type+spcOutlook.num),
                            title: titlePrefix + title
                        });
                        var polyline = new google.maps.Polyline({
                            path: paths,
                            geodesic: true,
                            strokeColor: color,
                            strokeOpacity: 1,
                            strokeWeight: 5,
                        });
                        //add phenom to that marker
                        google.maps.event.addListener(polygon, 'click', function(e) {
                            infoWindow.setContent("<div id='infoWindowContent'><b>" +
                                this.title.replace(/\n/g, '<BR><B>').replace(/:/g, ':</B>') +
                                //"<B>Event: " + spcOutlook.phenom + "</B><BR>" +
                                //"<B>Time:</B> " + spcOutlook.timestamp + " (UTC)<BR>" +
                                //"<B>Magnitude:</B> " + spcOutlook.mag + "<BR>" +
                                //"<B>City:</B> " + spcOutlook.city + ", " + spcOutlook.state + "<BR>" +
                                //"<B>County:</B> " + spcOutlook.county + "<BR>" +
                                //"<B>Source:</B> " + spcOutlook.source + "<BR>" +
                                //"<B>Remarks:</B> " + spcOutlook.remarks + "<BR>" +
                                "</div>");
                            infoWindow.setPosition(e.latLng);
                            infoWindow.open(map);
                        });
                        if (ahSpcOutlooks[outlookType].outlooks[spcOutlook.type])
                            ahSpcOutlooks[outlookType].outlooks[spcOutlook.type].push({ polygon: polygon, polyline: polyline });
                        else
                            ahSpcOutlooks[outlookType].outlooks[spcOutlook.type] = [{ polygon: polygon, polyline: polyline }];
                    }
                }
            }
        });
    }
    console.log('done fetching outlooks');
    toggleSpcOutlooks(requestedSpcOutlook);
    doneWaiting();
}

function toggleSpcOutlooks(category) {
    var outlookType = category.split('.');
    if (!ahSpcOutlooks || !ahSpcOutlooks[outlookType[0]] || !ahSpcOutlooks[outlookType[0]].outlooks[outlookType[1]]) return;
    if (ahSpcOutlooks[outlookType[0]].outlooks[outlookType[1]][0].polygon.getMap() == map) {   //markers already visible, remove them
        for (var i = 0; i < ahSpcOutlooks[outlookType[0]].outlooks[outlookType[1]].length; i++) {
            ahSpcOutlooks[outlookType[0]].outlooks[outlookType[1]][i].polygon.setMap(null);  
            ahSpcOutlooks[outlookType[0]].outlooks[outlookType[1]][i].polyline.setMap(null);  
            $("#preloadImagesBtn").prop("checked", false);
        }
    }
    else {  //remove the map
        for (i = 0; i < ahSpcOutlooks[outlookType[0]].outlooks[outlookType[1]].length; i++) {
            ahSpcOutlooks[outlookType[0]].outlooks[outlookType[1]][i].polygon.setMap(map);   //place marker on map
            ahSpcOutlooks[outlookType[0]].outlooks[outlookType[1]][i].polyline.setMap(map);   
            $("#preloadImagesBtn").prop("checked", true);
        }
    }
}
