/// <reference path="~/vsdocs/google-maps-3-vs-1-0.js" />
/// <reference path="gMapFunctions.js" />
/// <reference path="ahCore.js" />
/// <reference path="../map/radarSites.js" />

//create AllisonHouse Storm Report object (arrays will be stored within as properties)
var ahWatchWarns = {};
var requestedWatchWarn = null;
var ahPhenoms = {
    WINTER: { DownloadTime: new Date(0), BZ: { A: 'green', W: 'red' }, WS: { W: '#FF69B4', A: '4682B4' }, WW: { Y: '#7B68EE' }, IS: { W: 'purple' }, ZR: { Y: 'DA70D6' }, ZF: { Y: '008080' }, LE: { Y: 'lightgreen', W: 'orange', A: 'lime' } },
    FIRE:{DownloadTime:new Date(0),FW:{W:'orange',A:'yellow'}},
    TEMPERATURE:{DownloadTime:new Date(0),WC:{Y:'plum',W:'pink'},FZ:{A:'lightblue',W:'blue'},HA:{W:'blue'},EH:{A:'yellow'},HT:{Y:'orange'}},
    MARINE: { DownloadTime: new Date(0), GL: { W: 'plum', A: 'lightblue' }, SC: { A: 'D8BFD8', Y: 'D8BFD8' }, SR: { W: 'violet', A: 'green' }, LW: { Y: 'D2B48C' } },
    WIND:{DownloadTime:new Date(0),WI:{Y:'silver'},HW:{A:'yellow',W:'brown'},EW:{W:'darkred'},GL:{W:'#DDA0DD'}},
    FLOODING:{DownloadTime:new Date(0),FA:{A:'#2E8B57',W:'#3F9C68',Y:'#4FAD79'},FL:{W:'green',Y:'olive'}},
    TORNADO: { DownloadTime: new Date(0), SV: { A: 'orange', W: '#DB7093' }, TO: { A: 'yellow', W: 'red' }, FF: { A: 'red', W: 'darkred' } }
}; //array for all the phenoms

$(function () {
    $(".ahWatchWarnToggle").change(function () {
        requestedWatchWarn = this.getAttribute("data-reporttype");
        checkReportDownloadTime(requestedWatchWarn, $(this), ahPhenoms[requestedWatchWarn].DownloadTime, toggleWatchWarns, downloadAHWatchWarn);
    });
});

function downloadAHWatchWarn() {
    waitForIt();
    console.log("Starting fetch of AH Reports...");
    ahPhenoms[requestedWatchWarn].DownloadTime = new Date(); //record our time
    var reportCounter = 0;
    ahWatchWarns = { WINTER: {}, FIRE: {}, TEMPERATURE: {}, MARINE: {}, WIND: {}, FLOODING: {}, TORNADO: {}}; //array for all the storm report markers
    var phenoms = Object.keys(ahPhenoms[requestedWatchWarn]).map(function (c) { return "phenom[]=" + c; }).join('&');

    for (var siteNames in radarSites) {
        var url = "http://feeds.allisonhouse.com/" + allisonHousePToken + "/Watchwarn.json?site=" + siteNames +'&'+phenoms;

        $.getJSON(url, function (data) {
            for (var a in data) {
                for (var b in data[a]) {
                    for (var c in data[a][b]) {
                        var watchWarn = data[a][b][c];
                        if (watchWarn.VTEC_End < new Date()) continue;
                        if (!(requestedWatchWarn in ahPhenoms) || !(watchWarn.phenom in ahPhenoms[requestedWatchWarn]) || !(watchWarn.sig in ahPhenoms[requestedWatchWarn][watchWarn.phenom])) {
                            console.log(String.format("{0}: {1}.{2} does not exist.", requestedWatchWarn, watchWarn.phenom, watchWarn.sig));
                            continue;
                        }
                        var messageStart = watchWarn.contents.indexOf('...' + watchWarn.EnglishProdType.toUpperCase());
                        var messageEnd = watchWarn.contents.indexOf('...', messageStart + 3);
                        var remarks = watchWarn.contents.substr(messageStart+3, messageEnd - messageStart).replace(/\n/g, '');
                        var polygon = new google.maps.Polygon({
                            paths: watchWarn.usmap.POLY.slice(0, -1).split(':').map(function (c) {
                                return new google.maps.LatLng(c.split(',')[0], c.split(',')[1]);
                            }),
                            strokeColor: '#FFF',
                            strokeOpacity: 0.5,
                            strokeWeight: 1,
                            fillColor: ahPhenoms[requestedWatchWarn][watchWarn.phenom][watchWarn.sig],
                            fillOpacity: 0.7,
                            title: String.format('{0} {3} {1}.{2}', watchWarn.Action, watchWarn.phenom, watchWarn.sig, watchWarn.WatchNumber) +
                                "\nEvent: " + watchWarn.EnglishProdType +
                                "\nIssued (UTC): " + watchWarn.VTEC_Start +
                                "\nExpire (UTC): " + watchWarn.VTEC_End +
                                "\nCounty: " + watchWarn.usmap.COUNTYNAME +
                                "\nState: " + watchWarn.usmap.STATE +
                                "\nSource: " + watchWarn.Office +
                                "\nRemarks: " + remarks
                        });

                        //add phenom to that marker
                        google.maps.event.addListener(polygon, 'click', function(e) {
                            infoWindow.setContent("<div id='infoWindowContent'><b>" +
                                this.title.replace(/\n/g, '<BR><B>').replace(/:/g, ':</B>') +
                                //"<B>Event: " + watchWarn.phenom + "</B><BR>" +
                                //"<B>Time:</B> " + watchWarn.timestamp + " (UTC)<BR>" +
                                //"<B>Magnitude:</B> " + watchWarn.mag + "<BR>" +
                                //"<B>City:</B> " + watchWarn.city + ", " + watchWarn.state + "<BR>" +
                                //"<B>County:</B> " + watchWarn.county + "<BR>" +
                                //"<B>Source:</B> " + watchWarn.source + "<BR>" +
                                //"<B>Remarks:</B> " + watchWarn.remarks + "<BR>" +
                                "</div>");
                            infoWindow.setPosition(e.latLng);
                            infoWindow.open(map);
                        });
                        ahWatchWarns[requestedWatchWarn][watchWarn.UGC] = polygon;
                    }
                        //console.log(watchWarn.phenom); //show what just got pushed
                    }
            }
        }).done(function() {
            //console.log("getJSON complete for " + radarSiteNames[reportCounter]);
            reportCounter++;
            if (reportCounter == Object.keys(radarSites).length) {
                doneWaiting();
                console.log("all finished, " + reportCounter + " sites loaded. Took " + (new Date() - ahPhenoms[requestedWatchWarn].DownloadTime) / 1000 + " secs");
                toggleWatchWarns(requestedWatchWarn);
            }
        });
    }
}

function toggleWatchWarns(category) {
    if (!ahWatchWarns || !ahWatchWarns[category] || !ahWatchWarns[category][Object.keys(ahWatchWarns[category])[0]]) return;
    var watchWarnPoly;
    if (ahWatchWarns[category][Object.keys(ahWatchWarns[category])[0]].getMap() == map) {   //markers already visible, remove them
        for (watchWarnPoly in ahWatchWarns[category]) {
            ahWatchWarns[category][watchWarnPoly].setMap(null);   //remove marker
        }
        $("#preloadImagesBtn").prop("checked", false);
    }
    else {  //remove the map
        for (watchWarnPoly in ahWatchWarns[category]) {
            ahWatchWarns[category][watchWarnPoly].setMap(map);   //place marker on map
        }
        $("#preloadImagesBtn").prop("checked", true);
    }
}
