/// <reference path="jquery-1.10.2.min.js" />
/// <reference path="jquery-ui.min.js" />
/// <reference path="gMapCore.js" />
/// <reference path="gMapUI.js" />
/// <reference path="soundings.js" />
/// <reference path="ZeroClipboard.js" />
/// <reference path="~/www/phonegap.js" />
/// <reference path="~/vsdocs/google-maps-3-vs-1-0.js" />

$(function () {
    $("#slider").slider({
        orientation: "horizontal",
        value: .7,
        min: 0,
        max: 0.85,
        disabled: true,
        step: .01,
        slide: function (event, ui) {
            changeOpacity(ui.value);
        }
    });

    $(".inlineSlider").slider({
        orientation: "horizontal",
        value: .9,
        min: 0,
        max: 1.0,
        step: .01,
        slide: function (event, ui) {
            var layerID = $(this).attr("data-layerName");
            map.overlayMapTypes.j[overlayMaps[layerID].index].setOpacity(ui.value);
        }
    });
    $("#accordion").accordion({ collapsible: true, active: 0, heightStyle: "content" });
    $("input[type=submit], button, .btn").button();
    $("#timeFormatRadios").buttonset();
    $("#mapChoiceRadios").buttonset();
    $("#preloadImagesBtn").change(function () {
        var current = $("#preloadImagesBtn").prop("checked");
        if (current) {
            var choice = confirm("Are you sure? This will use a LOT of data.");
            if (!choice) {
                $("#preloadImagesBtn").prop("checked", false);
                preloadPreference = false;
            }
        }
        $(".btn").button("refresh");
        preloadPreference = $("#preloadImagesBtn").prop("checked");
        ga('send', 'event', 'preload', 'click', preloadPreference);
    });

    $('.layer').click(function () {
        var layerID = this.id;
        var overlayLayer = overlayMaps[layerID];
        if ($(this).prop('checked')) {
            var overlayMap = new google.maps.ImageMapType(overlayLayer);
            map.overlayMapTypes.setAt(overlayLayer.index, overlayMap);
            ga('send', 'event', 'underlay', 'click', 'added ' + layerID);
        } else {
            if (map.overlayMapTypes.getLength() > 0) {
                map.overlayMapTypes.setAt(overlayLayer.index, null);
                ga('send', 'event', 'underlay', 'click', 'removed ' + layerID);
            }
        }
    });

    document.getElementById('toggleGoogleWeather').addEventListener('change', function () {
        if (this.checked) {
            weatherLayer = new google.maps.weather.WeatherLayer({
                temperatureUnits: google.maps.weather.TemperatureUnit.FAHRENHEIT
            });
            weatherLayer.setMap(map);
        } else {
            weatherLayer.setMap(null);
        }
    });

    document.getElementById('toggleTraffic').addEventListener('change', function () {
        if (this.checked) {
            trafficLayer = new google.maps.TrafficLayer();
            trafficLayer.setMap(map);
        } else {
            trafficLayer.setMap(null);
        }
    });

    $("#saveMySettingsBtn").change(function () {
        var current = $("#saveMySettingsBtn").prop("checked");
        if (current) {
            saveMyView = true;
        }
        else {
            saveMyView = false;
        }
        ga('send', 'event', 'savesettings', 'click', saveMyView);
    });

    $("input[name='timeFormat']").change(function (e) {
        var timeFormat = this.value;
        if (timeFormat == "timeUTC") {
            utcInitPref = true;
            utcValidPref = true;
        }
        else if (timeFormat == "timeLocal") {
            utcInitPref = false;
            utcValidPref = false;
        }
        else if (timeFormat == "timeBoth") {
            utcInitPref = true;
            utcValidPref = false;
        }
        else {
            alert("There was a problem setting your time preference. If this keeps happening, please use the Feedback button in the preferences panel to send a trouble report.");
            return false;
        }
        var selectedModelButton = $("input[name='modelRadio']:checked").val();

        if (selectedModelButton != null) {
            var answer = confirm("Takes effect next time you select a model, or click OK to automatically re-select your current model now.");
            if (answer) {
                $('label[for=' + selectedModelButton + ']').click();
            }
        }
        ga('send', 'event', 'timesettings', 'click', 'init ' + utcInitPref + ' valid ' + utcValidPref);
    });

    $("input[name='mapChoice']").change(function () {
        dualMaps();
    });

    $("#overlayGuessesBtn").change(function () {
        var current = $("#overlayGuessesBtn").prop("checked");
        if (current) {
            overlayGuesses = true;
            showGuesses();
        }
        else {
            overlayGuesses = false;
            hideGuesses();
        }
        ga('send', 'event', 'targettracker', 'click', overlayGuesses);
    });

    $("#spotterHeatMapBtn").change(function () {
        var current = $("#spotterHeatMapBtn").prop("checked");
        if (current) {
            overlaySpotters = true;
            showSpotterNetwork();
        }
        else {
            overlaySpotters = false;
            hideSpotterNetwork();
        }
        ga('send', 'event', 'spotterlocations', 'click', overlaySpotters);
    });


    $("h3").bind("selectstart", function (e) {
        e.preventDefault();
    });
});

var hideShareMenu = function (e) {
    if (e.target.id != 'shareMenu' && $('#' + e.target.id).parent('#shareMenu').length == 0 && $('#' + e.target.id).parent('#shareButtons').length == 0) {
        document.getElementById('shareButtons').style.display = 'none';
        document.body.onclick = null;
    }
};

function preload(arrayOfImages) {
    $(arrayOfImages).each(function () {
        //$('<img/>')[0].src = this;
        // Alternatively you could use:
        (new Image()).src = this;
    });
}

//set some variables and default values
var displayedModelName = "", allisonHousePToken, initDateTimeSql, overlayMaps, utcInitPref = true, utcValidPref = true, displayedInitTime = "", displayedProductName = "", displayedProductDescription = "", displayedValidHour = ""
    , currentDisplayedHour = -1, heatmap, overlayImage1, oldOverlayImage1, overlayImage2, oldOverlayImage2, map, map2, destinationMap, preloadPreference = false, saveMyView = true, overlayGuesses = false, overlaySpotters = false
    , weatherLayer, trafficLayer, zoom = 5, currentMapTarget = map, myMapStyle = google.maps.MapTypeId.ROADMAP, center = new google.maps.LatLng(36, -97), infoWindow = new google.maps.InfoWindow('<div id=infoWindowContent></div>')
    , allProducts, infoWindowContent, imageBounds = new google.maps.LatLngBounds(new google.maps.LatLng(18.04, -125.5), new google.maps.LatLng(55.975, -66.5)); // sw, ne
var map1BoundsListener, map1TypeListener, map2BoundsListener, map2TypeListener, resetMap1Timeout, resetMap2Timeout, mouseUpListener = null, clickEvent = false;
ZeroClipboard.config({ moviePath: "/scr/ZeroClipboard.swf" });
var clipBoard = new ZeroClipboard();
function reloadSavedView() {
    try {
        var prefCookieString = getCookie("HNView");
        var prefCookie = prefCookieString && JSON.parse(prefCookieString);
        if (!prefCookie) return;
        if (prefCookie instanceof Array) {
            if (prefCookie[0]) {             //if 0th pref cookie is true, reload settings
                ga('send', 'event', 'savedview', 'event', 'reloaded from cookie values');
                console.log("Cookie found with true parameter, reloading saved settings...");
                zoom = prefCookie[3];
                center = new google.maps.LatLng(prefCookie[1], prefCookie[2]);
                $("#slider").slider("value", prefCookie[4]);
                myMapStyle = prefCookie[5];
            }
            saveMyView = prefCookie[0];
        }
        else if (prefCookie.saveMyView) {             //if 0th pref cookie is true, reload settings
            ga('send', 'event', 'savedview', 'event', 'reloaded from cookie values');
            console.log("Cookie found with true parameter, reloading saved settings...");
            zoom = prefCookie.zoom;
            center = new google.maps.LatLng(prefCookie.lat, prefCookie.lng);
            $("#slider").slider("value", prefCookie.opacity);
            myMapStyle = prefCookie.mapTypeId;
            allisonHousePToken = prefCookie.allisonHousePToken;
            if (prefCookie.utcInitPref !== undefined)
                utcInitPref = prefCookie.utcInitPref;
            if (prefCookie.utcValidPref !== undefined)
                utcValidPref = prefCookie.utcValidPref;
            saveMyView = prefCookie.saveMyView;
        }
        $("#saveMySettingsBtn").prop("checked", saveMyView);
        $(".btn").button("refresh");
    }
    catch (e) {
        console.log("No cookie found. One will be set when you leave the site. " + e);
    }
}

var mapInitializedEvent = document.createEvent('Event');
mapInitializedEvent.initEvent("mapinitialized", true, true);

function showShareMenu() {
    document.getElementById('shareMenu').style.display = "block";
    document.getElementById('drawMenu').style.display = "block";
    google.maps.event.trigger(map, 'resize');
}

function showShareButtons() {
    document.getElementById('shareButtons').style.display = "block";
    document.body.onclick = hideShareMenu;
    google.maps.event.trigger(map, 'resize');
}

function showDrawingTools() {
    document.getElementById('drawingTools').style.display = "block";
    drawingManager.setMap(map);
    google.maps.event.trigger(map, 'resize');
}

function initialize() {
    wordpressUserIdNumber = document.getElementById('hazwxu').value;
    wordpressUserHash = document.getElementById('hazwxh').value;
    if (!wordpressUserIdNumber || !wordpressUserHash) {
        var wordpressCookieString = getCookie('HazWx_WP_User');
        try {
            var wordpressCookie = wordpressCookieString && JSON.parse(wordpressCookieString);
        } catch (e) {
            setCookie('HazWx_WP_User', '', new Date(0));
        }
        if (wordpressCookie && wordpressCookie.userId && wordpressCookie.userHash) {
            wordpressUserIdNumber = wordpressCookie.userId;
            wordpressUserHash = wordpressCookie.userHash;
        }
    }
    reloadSavedView();

    var styledMap = new google.maps.StyledMapType(customMapStyles, { name: "HazWx Style" });

    var mapOptions = {
        zoom: zoom,
        draggable: true,
        center: center,
        disableDefaultUI: true,
        scrollwheel: true,
        maxZoom: 15,
        //minZoom: 5,
        mapTypeControl: true,
        mapTypeControlOptions: {
            mapTypeIds: [google.maps.MapTypeId.ROADMAP, google.maps.MapTypeId.HYBRID, google.maps.MapTypeId.TERRAIN, google.maps.MapTypeId.SATELLITE, 'map_style'],
            style: google.maps.MapTypeControlStyle.DROPDOWN_MENU,
            position: google.maps.ControlPosition.TOP_RIGHT
        },
        overviewMapControl: true,
        overviewMapControlOptions: {
            opened: false
        },
        zoomControl: true,
        zoomControlOptions: {
            style: google.maps.ZoomControlStyle.SMALL,
            position: google.maps.ControlPosition.TOP_RIGHT
        },
        mapTypeId: myMapStyle
    };

    console.log("Options for Map1 loaded.");

    var mapOptions2 = mapOptions;
    console.log("Options for Map2 loaded.");

    map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);
    map2 = new google.maps.Map(document.getElementById('map-canvas2'), mapOptions2);
    openSharedMap();

    var gpsButtonDiv = document.getElementById('centerOnUserBtn');
    gpsButtonDiv.index = 2;
    map.controls[google.maps.ControlPosition.RIGHT_TOP].push(gpsButtonDiv);

    var drawMenuDiv = document.getElementById('drawMenu');
    drawMenuDiv.index = 2;
    map.controls[google.maps.ControlPosition.TOP_RIGHT].push(drawMenuDiv);

    var shareMenuDiv = document.getElementById('shareMenu');
    shareMenuDiv.index = 2;
    map.controls[google.maps.ControlPosition.TOP_RIGHT].push(shareMenuDiv);


    document.getElementById('shareFacebook').onclick = shareToFacebook;
    document.getElementById('shareTwitter').onclick = shareToTwitter;
    document.getElementById('shareGoogle').onclick = shareToGoogle;
    document.getElementById('shareLink').onclick = shareLink;
    clipBoard = new ZeroClipboard(document.getElementById("copyShareLink"));
    clipBoard.on("ready", function (readyEvent) {
        clipBoard.on("copy", function (copyEvent) {
            copyEvent.clipboardData.setData('text/plain', copyEvent.relatedTarget.innerHTML);
            clipBoard.setTextcopyEvent.relatedTarget.innerHTML();
        });
        clipBoard.on('aftercopy', function (afterCopyEvent) {
            if (afterCopyEvent.success['text/plain']) {
                console.log('Copied text to clipboard: ' + afterCopyEvent.data['text/plain']);
            }
            else {
                console.log('Failed to copy text to clipboard: ' + afterCopyEvent.data['text/plain']);
            }
        });
        clipBoard.on('error', function (errorEvent) {
            console.log('ZeroClipboard error of type "' + errorEvent.name + '": ' + errorEvent.message);
            ZeroClipboard.destroy();
        });
    });

    var keyDiv = document.getElementById('colorKey');
    keyDiv.index = 2;
    map.controls[google.maps.ControlPosition.BOTTOM_CENTER].push(keyDiv);

    var creditsDiv = document.getElementById('credits');
    creditsDiv.index = 4;
    map.controls[google.maps.ControlPosition.BOTTOM_RIGHT].push(creditsDiv);

    var keyDiv2 = document.getElementById('colorKey2');
    keyDiv2.index = 1;
    map2.controls[google.maps.ControlPosition.BOTTOM_CENTER].push(keyDiv2);

    console.log("Finished pushing control elements to maps");

    google.maps.event.addListener(map, 'rightclick', function (event) {
        placeSounding(event.latLng, map);           //in soundings.js
    });
    google.maps.event.addListener(map2, 'rightclick', function (event) {
        placeSounding(event.latLng, map2);           //in soundings.js
    });

    //add event listener to map number 1
    map1BoundsListener = google.maps.event.addListener(map, 'bounds_changed', moveMap2);
    map1TypeListener = google.maps.event.addListener(map, 'maptypeid_changed', changeTypeMap2);
    map2BoundsListener = google.maps.event.addListener(map2, 'bounds_changed', moveMap1);
    map2TypeListener = google.maps.event.addListener(map2, 'maptypeid_changed', changeTypeMap1);
    google.maps.event.addListener(map, 'zoom_changed', updateZoomLayers);
    google.maps.event.addListener(map2, 'zoom_changed', updateZoomLayers);
    console.log("Event listeners added to maps");

    map.mapTypes.set('map_style', styledMap);
    map2.mapTypes.set('map_style', styledMap);
    map.setMapTypeId('map_style');

    destinationMap = map; //default map to push items onto

    setLoginText();
    getModels();
    getLogo(wordpressUserIdNumber, wordpressUserHash);

    overlayMaps = {
        NEXRAD: {
            getTileUrl: function (tile, zoom) {
                return "http://mesonet.agron.iastate.edu/cache/tile.py/1.0.0/nexrad-n0q-900913/" + zoom + "/" + tile.x + "/" + tile.y + ".png?" + (new Date()).getTime();
            },
            tileSize: new google.maps.Size(256, 256),
            opacity: 0.98,
            name: 'NEXRAD',
            isPng: true,
            index: 2
        },
        EAST: {
            getTileUrl: function (tile, zoom) {
                return "http://mesonet.agron.iastate.edu/cache/tile.py/1.0.0/goes-east-vis-1km-900913/" + zoom + "/" + tile.x + "/" + tile.y + ".png?" + (new Date()).getTime();
            },
            tileSize: new google.maps.Size(256, 256),
            opacity: 0.80,
            name: 'GOES East Vis',
            isPng: true,
            index: 1
        },
        WEST: {
            getTileUrl: function (tile, zoom) {
                return "http://mesonet.agron.iastate.edu/cache/tile.py/1.0.0/goes-west-vis-1km-900913/" + zoom + "/" + tile.x + "/" + tile.y + ".png?" + (new Date()).getTime();
            },
            tileSize: new google.maps.Size(256, 256),
            opacity: 0.80,
            name: 'GOES West Vis',
            isPng: true,
            index: 0
        }
    };

    for (var underlay in overlayMaps) {
        map.overlayMapTypes.push(null);
    }
    console.log("Underlay maps have been prepared and pushed to the MapTypes array.");
    var timeFormat = utcInitPref + utcValidPref;
    $('label[for=time' + timeFormat + ']').click();
    document.getElementById('time' + timeFormat).checked = true;

    google.maps.event.addListener(infoWindow, 'domready', function () {
        var l = $('#infoWindowContent').parent().parent();
        $(l).css('overflow', 'hidden');
        $(l).css('word-wrap', 'break-word');
    });

    console.log("Initialization routine is complete. Welcome to HazWx.com!");
    document.getElementById("loginText").dispatchEvent(mapInitializedEvent);
}

function moveMap2() {
    if (map2BoundsListener) map2BoundsListener = google.maps.event.removeListener(map2BoundsListener);
    map2.panTo(map.getCenter());
    map2.setZoom(map.getZoom());
    if (!resetMap2Timeout) resetMap2Timeout = setTimeout(resetMap2Listener, 1000);
    mouseUpListener = mouseUpListener || google.maps.event.addListener(map, 'mouseup', resetMap2Listener);
    //console.log('moving map2');
}

function moveMap1() {
    if (map1BoundsListener) map1BoundsListener = google.maps.event.removeListener(map1BoundsListener);
    map.panTo(map2.getCenter());
    map.setZoom(map2.getZoom());
    if (!resetMap1Timeout) resetMap1Timeout = setTimeout(resetMap1Listener, 1000);
    mouseUpListener = mouseUpListener || google.maps.event.addListener(map2, 'mouseup', resetMap1Listener);
    //console.log('moving map');
}

function resetMap2Listener() {
    map2BoundsListener = google.maps.event.addListener(map2, 'bounds_changed', moveMap1);
    //console.log('adding map2 listeners');
    google.maps.event.removeListener(mouseUpListener);
    resetMap2Timeout = clearTimeout(resetMap2Timeout);
    mouseUpListener = null;
    savePreferences();
}

function resetMap1Listener() {
    map1BoundsListener = google.maps.event.addListener(map, 'bounds_changed', moveMap2);
    //console.log('adding map1 listeners');
    google.maps.event.removeListener(mouseUpListener);
    resetMap1Timeout = clearTimeout(resetMap1Timeout);
    mouseUpListener = null;
    savePreferences();
}

function updateZoomLayers() {
    var currentZoom = map.getZoom();
    for (var i = 5; i < 9; i++) {
        if (i <= currentZoom) {
            $('.maxZoom' + i).hide();
            $('.minZoom' + i).show();
        } else {
            $('.maxZoom' + i).show();
            $('.minZoom' + i).hide();
        }
    }
}

function changeTypeMap1() {
    if (map1TypeListener) map1TypeListener = google.maps.event.removeListener(map1TypeListener);
    map.setMapTypeId(map2.mapTypeId);
    map1TypeListener = google.maps.event.addListener(map, 'maptypeid_changed', changeTypeMap2);
    console.log('changing map type');
}

function changeTypeMap2() {
    if (map2TypeListener) map2TypeListener = google.maps.event.removeListener(map2TypeListener);
    map2.setMapTypeId(map.mapTypeId);
    map2TypeListener = google.maps.event.addListener(map2, 'maptypeid_changed', changeTypeMap1);
    console.log('changing map2 type');
}

function dualMapsTest() {
    var leftMapDiv = document.getElementById("map-canvas");
    var rightMapDiv = document.getElementById("map-canvas2");
    console.log("Displaying dual maps...");
    leftMapDiv.className = "dualmap";
    rightMapDiv.className = "dualmap";

    google.maps.event.trigger(map2, 'resize');
    google.maps.event.trigger(map, 'resize');
}

function dualMaps() {
    var prefMapSide = $("input[name='mapChoice']:checked").val();
    var leftMapDiv = document.getElementById("map-canvas");
    var rightMapDiv = document.getElementById("map-canvas2");
    ga('send', 'event', 'dualview', 'setview', prefMapSide);

    if (prefMapSide == "one") {
        //hide second map
        console.log("Displaying only map 1...");
        leftMapDiv.className = "onemap";
        rightMapDiv.className = "onemap";
    }

    if (prefMapSide == "left" || prefMapSide == "right") {
        //show both maps
        console.log("Displaying dual maps...");
        leftMapDiv.className = "dualmap";
        rightMapDiv.className = "dualmap";
    }

    google.maps.event.trigger(map2, 'resize');
    google.maps.event.trigger(map, 'resize');
}

function launchHotSpot() {
    console.log("Launching TargetTracker entry form. If you don\'t see it, please enable popups.");
    window.open("http://hazwx.com/map/hotSpotEntry.html", "hotSpotEntry", "scrollbars=0,status=0,toolbar=0,location=0,menubar=0,directories=0,resizable=0,height=550,width=770");
}

function changeGradient() {
    var gradient = [
        'rgba(0, 255, 255, 0)',
        'rgba(0, 255, 255, 1)',
        'rgba(0, 191, 255, 1)',
        'rgba(0, 127, 255, 1)',
        'rgba(0, 63, 255, 1)',
        'rgba(0, 0, 255, 1)',
        'rgba(0, 0, 223, 1)',
        'rgba(0, 0, 191, 1)',
        'rgba(0, 0, 159, 1)',
        'rgba(0, 0, 127, 1)',
        'rgba(63, 0, 91, 1)',
        'rgba(127, 0, 63, 1)',
        'rgba(191, 0, 31, 1)',
        'rgba(255, 0, 0, 1)'
    ];
    heatmap.setOptions({
        gradient: heatmap.get('gradient') ? null : gradient
    });
}

function changeRadius() {
    heatmap.setOptions({ radius: heatmap.get('radius') ? null : 20 });
}

function getModels() {
    waitForIt();
    console.log("Fetching available models...");
    var url = "http://api.hazardnotifications.com/get_model_names/?user_id=" + wordpressUserIdNumber + "&user_pass=" + wordpressUserHash;
    $.getJSON(url, function (data) {
        var availableModels = "";
        availableModels += "American Domain<br>";
        for (var i = 0; i < data.american_model_list.length; i++) {
            availableModels += "<input type='radio' class='wideRadio' id='usmodel" + i + "' value='usmodel" + i + "' name='modelRadio' data-model='" + data.american_model_list[i] + "' /><label class='wideRadio' for='usmodel" + i + "'>" + data.american_model_list[i] + "</label>";
        }
        availableModels += "<br><br>European Domain<br>";
        for (var i = 0; i < data.european_model_list.length; i++) {
            availableModels += "<input type='radio' class='wideRadio' id='eumodel" + i + "' value='eumodel" + i + "' name='modelRadio' data-model='" + data.european_model_list[i] + "' /><label class='wideRadio' for='eumodel" + i + "'>" + data.european_model_list[i] + "</label>";
        }
        availableModels += "<br><br>Custom Models<br>";
        for (var i = 0; i < data.custom_model_list.length; i++) {
            availableModels += "<input type='radio' class='wideRadio' id='cumodel" + i + "' value='cumodel" + i + "' name='modelRadio' data-model='" + data.custom_model_list[i] + "' /><label class='wideRadio' for='cumodel" + i + "'>" + data.custom_model_list[i] + "</label>";
        }
        var buttonset = $("#modelRadios").html(availableModels).buttonset();    //write the radios of available models
        wireUpLabels(buttonset[0], getInitTimes);
    });
    if (wordpressUserIdNumber > 0) { goToPanel(1); }
    doneWaiting();
}

function getInitTimes() {
    waitForIt();
    if (clickEvent == true && this.type == 'radio') {
        clickEvent = false;
        return;
    }
    document.getElementById('initPanel').style.display = "none";
    $('.modelFieldPanel').remove();
    $('.productPanel').remove();
    document.getElementById('validPanel').style.display = "none";
    var labelRadio = this.type == 'radio' ? this : document.getElementById(this.getAttribute('for'));
    if (this.type != 'radio') clickEvent = true;
    var model = labelRadio.getAttribute('data-model');
    console.log("Fetching available initialization times for model " + model);
    displayedModelName = model;
    var url = "http://api.hazardnotifications.com/get_model_init_datetimes/?model_name=" + model + "&user_id=" + wordpressUserIdNumber + "&user_pass=" + wordpressUserHash;
    $.getJSON(url, function (data) {
        var availableInitTimes = "";
        for (var i = 0; i < data.datetimes.length; i++) {
            var friendlyInitTime = makeShortDate(makeDate(data.datetimes[i]), utcInitPref);
            availableInitTimes += "<input type=\'radio\' class=\'wideRadio\' id=\'initTime" + i + "' name='initRadio' data-model='" + model + "' data-datetime='" + data.datetimes[i] + "' /><label class='wideRadio' for='initTime" + i + "'>" + friendlyInitTime + "</label>";
        }
        var buttonset = $("#initTimeRadios").html(availableInitTimes).buttonset();    //write the radios of available init times and make it a button set.
        wireUpLabels(buttonset[0], getProducts);
        goToPanel(2);
        doneWaiting();
        document.getElementById('initPanel').style.display = "block";
    });
}

function getProducts() {
    waitForIt();
    if (clickEvent == true && this.type == 'radio') {
        clickEvent = false;
        return;
    }
    $('.modelFieldPanel').remove();      //remove all existing panel elements built for the menu item
    $('.productPanel').remove();
    document.getElementById('validPanel').style.display = "none";
    var labelRadio = this.type == 'radio' ? this : document.getElementById(this.getAttribute('for'));
    if (this.type != 'radio') clickEvent = true;
    var model = labelRadio.getAttribute('data-model');
    var datetime = labelRadio.getAttribute('data-datetime');
    console.log("Fetching available products for " + model + " at " + datetime);
    var initTime = makeDate(datetime);
    var friendlyInitTime = makeShortDate(initTime, utcInitPref);
    displayedInitTime = friendlyInitTime;
    initDateTimeSql = datetime;
    var url = "http://api.hazardnotifications.com/get_model_products/?model_name=" + model + "&model_init_datetime=" + datetime + "&user_id=" + wordpressUserIdNumber + "&user_pass=" + wordpressUserHash;
    $.getJSON(url, function (data) {
        var productsHtml = "<h3 class='modelFieldPanel' id='modelFieldHeader'>Model Fields</h3><div class='modelFieldPanel'><div class='modelFieldPanel' id='modelFieldRadios'>"; //create header and div for radios
        allProducts = data;
        for (var menu in data['products']) {                    //for each top level menu:
            var friendlyMenu = menu.replace(/_/g, " ");         //create a friendly menu header name (title)
            productsHtml += "<input type='radio' class='modelFieldPanel wideRadio' id='modelField" + menu + "' name='prodCategoryRadio' data-category='" + menu
                + "' data-title='" + friendlyMenu + "' /><label class='wideRadio' for='modelField" + menu + "' title='" + friendlyMenu + "'>" + friendlyMenu + "</label>";
        }                                                       //repeat for next category
        productsHtml += "</div></div>";                     //end the radio button section
        $('#controlPanelSeparator').before(productsHtml);   //insert the new menu panel
        var buttonset = $("#modelFieldRadios").buttonset();                   //convert radios to styled buttons
        wireUpLabels(buttonset[0], showProduct);
        $("#accordion").accordion("refresh");                 //refresh the accordion menu
        goToPanel(3);
        doneWaiting();
    });
}

function showProduct() {
    if (clickEvent == true && this.type == 'radio') {
        clickEvent = false;
        return;
    }
    $('.productPanel').remove();
    document.getElementById('validPanel').style.display = "none";
    var labelRadio = this.type == 'radio' ? this : document.getElementById(this.getAttribute('for'));
    if (this.type != 'radio') clickEvent = true;
    var modelField = labelRadio.getAttribute('data-category');
    var friendlyMenu = modelField.replace(/_/g, " ");         //create a friendly menu header name (title)
    var productsHtml = "<h3 class='productPanel' id='" + modelField + "Header'>" + friendlyMenu + "</h3><div class='productPanel'><div class='productPanel' id='" + modelField + "Radios'>"; //create header and div for radios
    for (var i = 0; i < allProducts['products'][modelField].length; i++) {      //for each product in the modelField, create a radio button
        var title = allProducts['products'][modelField][i].description;
        var friendlyName = allProducts['products'][modelField][i].friendly_name;
        var allowed = allProducts['products'][modelField][i].available_to_user;
        var disabledString = "";
        var disabledTip = "Upgrade your subscription to view this product";
        if (allowed != true) { disabledString = "disabled"; title = disabledTip; }
        productsHtml += "<input " + disabledString + " type='radio' class='productPanel wideRadio' id='product" + modelField + i + "' name='prodRadio' data-model='"
            + allProducts.model_name + "' data-datetime='" + allProducts.model_init_datetime + "' data-product='" + allProducts['products'][modelField][i].product_file_prefix
            + "' data-title='" + title + "' /><label class='wideRadio' for='product" + modelField + i + "' title='" + title + "'>" + friendlyName + "</label>";
    }
    productsHtml += "</div></div>";                     //end the radio button section
    $('#controlPanelSeparator').before(productsHtml);   //insert the new menu panel
    var buttonset = $("#" + modelField + "Radios").buttonset();                   //convert radios to styled buttons
    wireUpLabels(buttonset[0], getImages);
    $("#accordion").accordion("refresh");                 //refresh the accordion menu
    goToPanel(4);
}

function showGuesses() {
    waitForIt();
    console.log("Fetching TargetTracker spots...");
    var endDate = new Date();
    var beginDate = new Date();
    beginDate.setDate(endDate.getDate() - 1);
    var url = "http://api.hazardnotifications.com/get_guesses/?start_date=" + getSQLTimeString(beginDate) + "&end_date=" + getSQLTimeString(endDate);
    $.getJSON(url, function (data) {
        var guessPoints = [];
        for (var i = 0; i < data.guess_list.length; i++) {
            var lat = data.guess_list[i].lat;
            var lon = data.guess_list[i].lon;
            var loc = new google.maps.LatLng(lat, lon);
            guessPoints.push(loc);
        }
        var pointArray = new google.maps.MVCArray(guessPoints);
        heatmap = new google.maps.visualization.HeatmapLayer({ data: pointArray });
        heatmap.setMap(map);
        changeRadius(); changeGradient();
    });
    setTimeout("doneWaiting();", 2000);
}

function hideGuesses() {
    console.log("Clearing TargetTracker spots...");
    heatmap.setMap(null);
}

function showSpotterNetwork() {
    waitForIt();
    console.log("Fetching SpotterNetwork spots...");
    var url = "http://api.hazardnotifications.com/sn_positions.json";
    var spotterNetworkPoints = [];		//create array

    $.getJSON(url, function (data) {
        for (var i = 0; i < data.length; i++) {
            var lat = data[i].lat;
            var lon = data[i].lon;
            var loc = new google.maps.LatLng(lat, lon);
            spotterNetworkPoints.push(loc);
        }
        var SNpointArray = new google.maps.MVCArray(spotterNetworkPoints);
        spotterheatmap = new google.maps.visualization.HeatmapLayer({ data: SNpointArray });
        spotterheatmap.setMap(map);
    });

    $("#credits").html("&copy; <a href='http://spotternetwork.org' target='_blank'>SpotterNetwork.org</a>");
    setTimeout("doneWaiting();", 2000);
}

function hideSpotterNetwork() {
    console.log("Clearing SpotterNetwork spots...");
    spotterheatmap.setMap(null);
    $("#credits").html("&copy; 2014");
}

function showSNReports() {      //to do later
    waitForIt(); //turn on progress indicator
    console.log("Fetching SpotterNetwork storm reports ...");
    var url = "http://api.hazardnotifications.com/sn_reports.json";
    var spotterNetworkPoints = [];		//create array

    $.getJSON(url, function (data) {
        for (var i = 0; i < data.length; i++) {
            var lat = data[i].lat;
            var lon = data[i].lon;
            var loc = new google.maps.LatLng(lat, lon);
            spotterNetworkPoints.push(loc);
        }
        var SNpointArray = new google.maps.MVCArray(spotterNetworkPoints);
        spotterheatmap = new google.maps.visualization.HeatmapLayer({ data: SNpointArray });
        spotterheatmap.setMap(map);
    });

    $("#credits").html("&copy; <a href='http://spotternetwork.org' target='_blank'>SpotterNetwork.org</a>");
    setTimeout("doneWaiting();", 2000);
}

function getImages() {
    if (clickEvent == true && this.type == 'radio') {
        clickEvent = false;
        return;
    }
    var labelRadio = this.type == 'radio' ? this : document.getElementById(this.getAttribute('for'));
    if (this.type != 'radio') clickEvent = true;
    var model = labelRadio.getAttribute('data-model');
    var datetime = labelRadio.getAttribute('data-datetime');
    var product = labelRadio.getAttribute('data-product');
    displayedProductName = labelRadio.getAttribute('data-title');;
    if (labelRadio.disabled == true) {
        alert("Please purchase a subscription to view this product");
        return;
    }
    ga('send', 'event', 'model', 'select', model);
    ga('send', 'event', 'product', 'select', product);
    ga('send', 'event', 'datetime', 'select', datetime);
    ga('send', 'event', 'full model', 'select', model + " " + product + " " + datetime);
    waitForIt();
    console.log("Fetching available images for " + model + " at " + datetime + " for " + product);
    var url = "http://api.hazardnotifications.com/get_model_images/?model_name=" + model + "&model_init_datetime=" + datetime + "&product_file_prefix=" + product + "&user_id=" + wordpressUserIdNumber + "&user_pass=" + wordpressUserHash;
    $.getJSON(url, function (data) {
        var validTimesHtml = "";
        var preloadParams = [];
        var initTime = makeDate(datetime);
        var friendlyInitTime = makeShortDate(initTime, utcInitPref);
        var colorBarUri = data.file_list[0].colorbar_url;
        var neLat = data.ne_lat; console.log("neLat: " + neLat);
        var neLon = data.ne_lon; console.log("neLonm: " + neLon);
        var swLat = data.sw_lat; console.log("swLat: " + swLat);
        var swLon = data.sw_lon; console.log("swLon: " + swLon);
        var cLat = data.center_lat; console.log("cLat: " + cLat);
        var cLon = data.center_lon; console.log("cLon: " + cLon);
        var minZoom = data.min_zoom; console.log("minZoom: " + minZoom);
        var maxZoom = data.max_zoom; console.log("maxZoom: " + maxZoom);
        for (var i = 0; i < data.file_list.length; i++) {
            var imagePath = data.file_list[i].file_url;
            var validHour = data.file_list[i].forecast_hour;
            var offsetTime = new Date(initTime.getTime() + validHour * 60000 * 60);
            var shortDate = makeShortDate(offsetTime, utcValidPref);
            if (validHour == 0) {
                validTimesHtml += "Days 1-2<br>";
            }
            if (validHour == 48) {
                validTimesHtml += "<br><br>Days 3-8<br>";
            }
            if (validHour == 192) {
                validTimesHtml += "<br><br>Days 9+<br>";
            }

            validHour = formatValidHour(validHour);

            validTimesHtml += String.format("<input type='radio' id='validTime{0}' data-colorBarUri='{1}' data-shortDate='{2}' data-validHour='{0}' data-imagePath='{3}' name='validRadio' data-neLat='{4}' data-neLon='{5}' data-swLat='{6}' data-swLon='{7}' data-cLat='{8}' data-cLon='{9}' data-minZoom='{10}' data-maxZoom='{11}' /><label title='{2}' class='validHourRadio' for='validTime{0}'>{0}</label>", validHour, colorBarUri, shortDate, imagePath, neLat, neLon, swLat, swLon, cLat, cLon, minZoom, maxZoom);
            preloadParams.push(imagePath);
        }
        validTimesHtml += "<br><br>Tip: (Re)select product to refresh available hours.";

        if (preloadPreference) {
            preload(preloadParams);
        }
        var buttonset = $("#validRadios").html(validTimesHtml).buttonset();         //write the radios of available init times and make it a button set.
        wireUpLabels(buttonset[0], validTimeRadioOnClick);

        if (currentDisplayedHour >= 0) {
            $("#validTime" + currentDisplayedHour).click();
            goToPanel(-3);
        }
        else {
            //$("#validTime"+"0").click();
            goToPanel(-3);
        }

        if (displayedModelName == "RTMA" && $("input[name='mapChoice']:checked").val() == "one") {
            $("label[for=validTime" + "0]").click();
        }
        else {
            goToPanel(-3);
        }

        doneWaiting();
        document.getElementById('validPanel').style.display = "block";
    });
}

function formatValidHour(original) {
    var hours = Math.floor(original);			//1.25
    var minutes = "00";
    var remainder = original - hours;
    var newValidHourString = original;
    if (remainder != 0) {
        minutes = remainder * 60;
        newValidHourString = hours + ":" + minutes;
        return newValidHourString;
    }
    return newValidHourString;
}

function validTimeRadioOnClick() {
    if (clickEvent == true && this.type == 'radio') {
        clickEvent = false;
        return;
    }
    var labelRadio = this.type == 'radio' ? this : document.getElementById(this.getAttribute('for'));
    if (this.type != 'radio') clickEvent = true;
    var colorBarUri = labelRadio.getAttribute("data-colorBarUri");
    var shortDate = labelRadio.getAttribute("data-shortDate");
    var validHour = labelRadio.getAttribute("data-validHour");
    var imagePath = labelRadio.getAttribute("data-imagePath");
    var neLat = labelRadio.getAttribute("data-neLat");
    var neLon = labelRadio.getAttribute("data-neLon");
    var swLat = labelRadio.getAttribute("data-swLat");
    var swLon = labelRadio.getAttribute("data-swLon");
    var cLat = labelRadio.getAttribute("data-cLat");
    var cLon = labelRadio.getAttribute("data-cLon");
    var minZoom = labelRadio.getAttribute("data-minZoom");
    var maxZoom = labelRadio.getAttribute("data-maxZoom");
    newColorBar(colorBarUri);
    displayedValidHour = shortDate;
    currentDisplayedHour = validHour;
    //newOverlay(imagePath);
    newCustomOverlay(imagePath, swLat, swLon, neLat, neLon);
    if (cLat != "null" && cLon != "null") {
        var newCenter = new google.maps.LatLng(cLat, cLon);
        map.panTo(newCenter);
        console.log(cLat + ", " + cLon);
        map.setZoom(8);
    }
    //map.setOptions({maxZoom: maxZoom, minZoom: minZoom});

}

function waitForIt() {
    $('body').addClass('progress');
}

function doneWaiting() {
    $('body').removeClass('progress');
}

function newOverlay(imageUri) {
    waitForIt();
    ga('send', 'event', 'image', 'load', imageUri);
    var prefMapSide = $("input[name='mapChoice']:checked").val();
    console.log("Sending new product to the map from source: " + imageUri + " to " + prefMapSide + " map");;
    var opacity = $("#slider").slider("value"); //save user's current opacity setting
    console.log("Got opacity");
    if (prefMapSide == "right") {
        destinationMap = map2;

        if (overlayImage2) {
            oldOverlayImage2 = overlayImage2;
        }

        overlayImage2 = new google.maps.GroundOverlay(   //create ground overlay object
            imageUri, imageBounds, { opacity: opacity, clickable: false }
        );

        overlayImage2.setMap(destinationMap);                       //display overlay object

        if (oldOverlayImage2) {
            oldOverlayImage2.setMap(null);
        }
    }
    else {
        destinationMap = map;
        console.log("set destination");
        if (overlayImage1) {
            oldOverlayImage1 = overlayImage1;
        }
        console.log("backup current image");//create ground overlay object
        overlayImage1 = new google.maps.GroundOverlay(
            imageUri, imageBounds, { opacity: opacity, clickable: false }
        );
        console.log("set image " + opacity);
        overlayImage1.setMap(destinationMap);                       //display overlay object
        console.log("set map");
        if (oldOverlayImage1) {
            oldOverlayImage1.setMap(null);
        }
    }
    console.log("done");
    $("#slider").slider("enable");                  //enable opacity slider control
    setMapTitle();
    showShareMenu();
    setTimeout("doneWaiting();", 2000);
}

function newCustomOverlay(imageUri, swLat, swLon, neLat, neLon) {
    waitForIt();
    ga('send', 'event', 'image', 'load', imageUri);
    swCorner = new google.maps.LatLng(swLat, swLon);
    neCorner = new google.maps.LatLng(neLat, neLon);
    imageCustomBounds = new google.maps.LatLngBounds(swCorner, neCorner); // sw, ne
    var prefMapSide = $("input[name='mapChoice']:checked").val();
    console.log("Sending new product to the map from source: " + imageUri + " to " + prefMapSide + " map");;
    var opacity = $("#slider").slider("value"); //save user's current opacity setting
    console.log("Got opacity");
    if (prefMapSide == "right") {
        destinationMap = map2;

        if (overlayImage2) {
            oldOverlayImage2 = overlayImage2;
        }

        overlayImage2 = new google.maps.GroundOverlay(   //create ground overlay object
            imageUri, imageCustomBounds, { opacity: opacity, clickable: false }
        );

        overlayImage2.setMap(destinationMap);                       //display overlay object

        if (oldOverlayImage2) {
            oldOverlayImage2.setMap(null);
        }
    }
    else {
        destinationMap = map;
        console.log("set destination");
        if (overlayImage1) {
            oldOverlayImage1 = overlayImage1;
        }
        console.log("backup current image");//create ground overlay object
        overlayImage1 = new google.maps.GroundOverlay(
            imageUri, imageCustomBounds, { opacity: opacity, clickable: false }
        );
        console.log("set image " + opacity);
        overlayImage1.setMap(destinationMap);                       //display overlay object
        console.log("set map");
        if (oldOverlayImage1) {
            oldOverlayImage1.setMap(null);
        }
    }
    console.log("done");
    $("#slider").slider("enable");                  //enable opacity slider control
    setMapTitle();
    showShareMenu();
    setTimeout("doneWaiting();", 2000);
}

function setMapTitle(title) {
    console.log("setting map title bar");
    var prefMapSide = $("input[name='mapChoice']:checked").val();
    var spaceHtml = "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
    title = title || displayedModelName + " from " + displayedInitTime + spaceHtml + displayedProductName + spaceHtml + "Hour " + currentDisplayedHour + ", " + displayedValidHour;
    if (prefMapSide == "right") {
        $("#mapTitle2").html(title);
    }
    else {
        $("#mapTitle").html(title);
    }
}

function newColorBar(url) {
    console.log("setting new color bar with URL: " + url);
    var prefMapSide = $("input[name='mapChoice']:checked").val();
    if (prefMapSide == "right") {
        $("#colorBarImg2").attr("src", url);
        document.getElementById("colorBarImg2").style.display = "block";
    }
    else {
        $("#colorBarImg").attr("src", url);
        document.getElementById("colorBarImg").style.display = "block";
    }
}

function changeOpacity(amount) {
    console.log("Changing opacity to " + amount);
    overlayImage1.setOpacity(amount);
    if (overlayImage2) {
        overlayImage2.setOpacity(amount);
    }
}

function changeLayerOpacity(layer, amount) {
    console.log("Changing opacity for " + layer + " to " + amount);
    layer.setOpacity(amount);
}

function savePreferences() {
    console.log("Attempting to save preferences cookie...");
    var hnViewPref = {};
    var c = map.getCenter();
    hnViewPref.saveMyView = saveMyView;  //boolean: true=save my preferences
    hnViewPref.lat = c.lat();     //current center lat point
    hnViewPref.lng = c.lng();     //current center lon point
    hnViewPref.zoom = map.getZoom();      //current zoom level
    hnViewPref.opacity = $("#slider").slider("value");  //current opacity level
    hnViewPref.mapTypeId = map.getMapTypeId(); //current map style
    hnViewPref.allisonHousePToken = allisonHousePToken;      //allisonHousePToken value
    hnViewPref.utcInitPref = utcInitPref;
    hnViewPref.utcValidPref = utcValidPref;

    var myJsonString = JSON.stringify(hnViewPref);
    setCookie("HNView", myJsonString);

    ga('send', 'event', 'last state', 'zoom', hnViewPref.zoom);
    ga('send', 'event', 'last state', 'opacity', hnViewPref.opacity);
    ga('send', 'event', 'last state', 'mapStyle', hnViewPref.mapTypeId);
}

function openSharedMap() {
    var shareParam = getParameterByName('share');
    if (!shareParam) return;
    var hnView = JSON.parse(atob(shareParam));
    ga('send', 'event', 'sharedview', 'event', 'reloaded from shared map');
    console.log("Cookie found with true parameter, reloading saved settings...");
    zoom = hnView.zoom;
    center = new google.maps.LatLng(hnView.lat, hnView.lng);
    $("#slider").slider("value", hnView.opacity);
    myMapStyle = hnView.mapTypeId;
    if (hnView.utcInitPref !== undefined)
        utcInitPref = hnView.utcInitPref;
    if (hnView.utcValidPref !== undefined)
        utcValidPref = hnView.utcValidPref;

    map.setMapTypeId(myMapStyle);
    map.setCenter(center);
    map.setZoom(zoom);
    hnView.overlayImage1 && newOverlay(decodeURI(hnView.overlayImage1));
    hnView.overlayImage2 && newOverlay(decodeURI(hnView.overlayImage2));
    //displayedValidHour = hnView.displayedValidHour;
    //currentDisplayedHour = hnView.currentDisplayedHour;
    hnView.colorBar1 && newColorBar(decodeURI(hnView.colorBar1));
    setMapTitle(hnView.mapTitle1);
}

function shareMap() {
    var c = map.getCenter();
    var hnView = {
        lat: c.lat(),     //current center lat point
        lng: c.lng(),     //current center lon point
        zoom: map.getZoom(),      //current zoom level
        opacity: $("#slider").slider("value"),  //current opacity level
        mapTypeId: map.getMapTypeId(), //current map style
        allisonHousePToken: allisonHousePToken,      //allisonHousePToken value
        utcInitPref: utcInitPref,
        utcValidPref: utcValidPref,         //boolean: true=display valid times in local
        overlayImage1: overlayImage1 && encodeURI(overlayImage1.getUrl()),
        overlayImage2: overlayImage2 && encodeURI(overlayImage2.getUrl()),
        colorBar1: encodeURI(document.getElementById('colorBarImg').getAttribute('src')),
        colorBar2: encodeURI(document.getElementById('colorBarImg2').getAttribute('src')),
        mapTitle1: $("#mapTitle").html(),
        mapTitle2: $("#mapTitle2").html(),
        //displayedValidHour: displayedValidHour,
        //currentDisplayedHour: currentDisplayedHour,
        underlays: {},
        traffic: document.getElementById('toggleTraffic').checked
    };
    return btoa(JSON.stringify(hnView));
}

function centerOnUserLocation() {
    navigator.geolocation.getCurrentPosition(onGpsSuccess, onGpsError);
}

function shareToFacebook(e) {
    var fbShareUrl = "https://www.facebook.com/dialog/feed?app_id=798871373463660&display=popup&link=http://hazwx.com/maps/?share=" +
        shareMap() + "&redirect_uri=http://hazwx.com/thanks&picture=http://hazwx.com/img/sharedmapimg.png&name=" + displayedProductName +
        "&caption=" + displayedModelName + " run from " + displayedInitTime + ", valid for " + displayedValidHour +
        "&description=View this shared weather map from HazWx.com";
    window.open(encodeURI(fbShareUrl), '_system', 'location=no,menubar=no,status=no,toolbar=no,titlebar=no,height=360,width=680');
    e.stopPropagation();
}

function shareToTwitter(e) {
    //recommended size from twitter is 550x420
    //image resources: https://dev.twitter.com/docs/image-resources
    var twShareUrl = "https://twitter.com/intent/tweet?via=haznotification&text=" +
        displayedModelName + ": " + displayedProductName + ", valid " + displayedValidHour + "&url=";
    shortenURL("http://hazwx.com/maps/?share=" + shareMap(), function (url) {
        window.open(encodeURI(twShareUrl) + url.replace('#', '%23'), '_system', 'location=no,menubar=no,status=no,toolbar=no,titlebar=no,height=420,width=550');
    });
    e.stopPropagation();
}

function shareToGoogle(e) {
    //image resources: https://developers.google.com/+/web/share/
    var goShareUrl = "https://plus.google.com/share?url=http://hazwx.com/maps/?share=" + shareMap();
    window.open(encodeURI(goShareUrl), '_system', 'location=no,menubar=no,status=no,toolbar=no,titlebar=no,height=420,width=550');
    e.stopPropagation();
}

function shareLink(e) {
    shortenURL("http://hazwx.com/maps/?share=" + shareMap(), function (url) {
        document.getElementById('shareLinkText').innerHTML = url;
        $('#copyShareLink').show();
    });
    e.stopPropagation();
}

var onGpsSuccess = function (position) {
    map.panTo(new google.maps.LatLng(position.coords.latitude, position.coords.longitude));
    map.setZoom(map.getZoom());
    console.log('Latitude: ' + position.coords.latitude + '\n' +
        'Longitude: ' + position.coords.longitude + '\n' +
        'Altitude: ' + position.coords.altitude + '\n' +
        'Accuracy: ' + position.coords.accuracy + '\n' +
        'Altitude Accuracy: ' + position.coords.altitudeAccuracy + '\n' +
        'Heading: ' + position.coords.heading + '\n' +
        'Speed: ' + position.coords.speed + '\n' +
        'Timestamp: ' + position.timestamp + '\n');
};

function onGpsError(error) {
    console.log('code: ' + error.code + '\n' +
        'message: ' + error.message + '\n');
}

function hideDrawingTools() {
    document.getElementById('drawingTools').style.display = "none";
    drawingManager.setMap(null);
}